@@ -33,13 +33,13 @@ using namespace poppler;
 
 static void stderr_debug_function(const std::string &msg, void * /*data*/)
 {
-    std::cerr << "poppler/" << msg;
+    std::cerr << "poppler/" << msg << std::endl;
 }
 
 debug_func detail::user_debug_function = stderr_debug_function;
 void *detail::debug_closure = nullptr;
 
-void detail::error_function(void * /*data*/, ErrorCategory /*category*/, Goffset pos, char *msg)
+void detail::error_function(void * /*data*/, ErrorCategory /*category*/, Goffset pos, const char *msg)
 {
     std::ostringstream oss;
     if (pos >= 0) {
