@@ -14,8 +14,9 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2008 Koji Otani <sho@bbr.jp>
-// Copyright (C) 2009 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -25,18 +26,12 @@
 #ifndef CMAP_H
 #define CMAP_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
+#include <atomic>
 
 #include "poppler-config.h"
 #include "goo/gtypes.h"
 #include "CharTypes.h"
 
-#ifdef MULTITHREADED
-#include "goo/GooMutex.h"
-#endif
-
 class GooString;
 class Object;
 struct CMapVectorEntry;
@@ -50,27 +45,30 @@ public:
 
   // Parse a CMap from <obj>, which can be a name or a stream.  Sets
   // the initial reference count to 1.  Returns NULL on failure.
-  static CMap *parse(CMapCache *cache, GooString *collectionA, Object *obj);
+  static CMap *parse(CMapCache *cache, const GooString *collectionA, Object *obj);
 
   // Create the CMap specified by <collection> and <cMapName>.  Sets
   // the initial reference count to 1.  Returns NULL on failure.
-  static CMap *parse(CMapCache *cache, GooString *collectionA,
-		     GooString *cMapNameA);
+  static CMap *parse(CMapCache *cache, const GooString *collectionA,
+		     const GooString *cMapNameA);
 
   // Parse a CMap from <str>.  Sets the initial reference count to 1.
   // Returns NULL on failure.
-  static CMap *parse(CMapCache *cache, GooString *collectionA, Stream *str);
+  static CMap *parse(CMapCache *cache, const GooString *collectionA, Stream *str);
 
   // Create the CMap specified by <collection> and <cMapName>.  Sets
   // the initial reference count to 1.
   // Stream is a stream containing the CMap, can be NULL and 
   // this means the CMap will be searched in the CMap files
   // Returns NULL on failure.
-  static CMap *parse(CMapCache *cache, GooString *collectionA,
-		     GooString *cMapNameA, Stream *stream);
+  static CMap *parse(CMapCache *cache, const GooString *collectionA,
+		     const GooString *cMapNameA, Stream *stream);
 
   ~CMap();
 
+  CMap(const CMap &) = delete;
+  CMap& operator=(const CMap &) = delete;
+
   void incRefCnt();
   void decRefCnt();
 
@@ -81,12 +79,12 @@ public:
 
   // Return true if this CMap matches the specified <collectionA>, and
   // <cMapNameA>.
-  GBool match(GooString *collectionA, GooString *cMapNameA);
+  bool match(const GooString *collectionA, const GooString *cMapNameA);
 
   // Return the CID corresponding to the character code starting at
   // <s>, which contains <len> bytes.  Sets *<c> to the char code, and
   // *<nUsed> to the number of bytes used by the char code.
-  CID getCID(char *s, int len, CharCode *c, int *nUsed);
+  CID getCID(const char *s, int len, CharCode *c, int *nUsed);
 
   // Return the writing mode (0=horizontal, 1=vertical).
   int getWMode() { return wMode; }
@@ -108,15 +106,12 @@ private:
 
   GooString *collection;
   GooString *cMapName;
-  GBool isIdent;		// true if this CMap is an identity mapping,
+  bool isIdent;		// true if this CMap is an identity mapping,
 				//   or is based on one (via usecmap)
   int wMode;			// writing mode (0=horizontal, 1=vertical)
   CMapVectorEntry *vector;	// vector for first byte (NULL for
 				//   identity CMap)
-  int refCnt;
-#ifdef MULTITHREADED
-  GooMutex mutex;
-#endif
+  std::atomic_int refCnt;
 };
 
 //------------------------------------------------------------------------
@@ -129,13 +124,16 @@ public:
   CMapCache();
   ~CMapCache();
 
+  CMapCache(const CMapCache &) = delete;
+  CMapCache& operator=(const CMapCache &) = delete;
+
   // Get the <cMapName> CMap for the specified character collection.
   // Increments its reference count; there will be one reference for
   // the cache plus one for the caller of this function.
   // Stream is a stream containing the CMap, can be NULL and 
   // this means the CMap will be searched in the CMap files
   // Returns NULL on failure.
-  CMap *getCMap(GooString *collection, GooString *cMapName, Stream *stream);
+  CMap *getCMap(const GooString *collection, const GooString *cMapName, Stream *stream);
 
 private:
 
