@@ -15,11 +15,12 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006, 2007 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2006, 2010 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2008 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2008, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -29,9 +30,7 @@
 #ifndef CAIROFONTENGINE_H
 #define CAIROFONTENGINE_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
+#include <mutex>
 
 #include "poppler-config.h"
 #include "goo/gtypes.h"
@@ -48,16 +47,18 @@ public:
 	    cairo_font_face_t *face,
 	    int *codeToGID,
 	    Guint codeToGIDLen,
-	    GBool substitute,
-	    GBool printing);
+	    bool substitute,
+	    bool printing);
   virtual ~CairoFont();
+  CairoFont(const CairoFont &) = delete;
+  CairoFont& operator=(const CairoFont &other) = delete;
 
-  virtual GBool matches(Ref &other, GBool printing);
+  virtual bool matches(Ref &other, bool printing);
   cairo_font_face_t *getFontFace(void);
   unsigned long getGlyph(CharCode code, Unicode *u, int uLen);
   double getSubstitutionCorrection(GfxFont *gfxFont);
 
-  GBool isSubstitute() { return substitute; }
+  bool isSubstitute() { return substitute; }
 protected:
   Ref ref;
   cairo_font_face_t *cairo_font_face;
@@ -65,20 +66,20 @@ protected:
   int *codeToGID;
   Guint codeToGIDLen;
 
-  GBool substitute;
-  GBool printing;
+  bool substitute;
+  bool printing;
 };
 
 //------------------------------------------------------------------------
 
 class CairoFreeTypeFont : public CairoFont {
 public:
-  static CairoFreeTypeFont *create(GfxFont *gfxFont, XRef *xref, FT_Library lib, GBool useCIDs);
+  static CairoFreeTypeFont *create(GfxFont *gfxFont, XRef *xref, FT_Library lib, bool useCIDs);
   ~CairoFreeTypeFont();
 
 private:
   CairoFreeTypeFont(Ref ref, cairo_font_face_t *cairo_font_face,
-	    int *codeToGID, Guint codeToGIDLen, GBool substitute);
+	    int *codeToGID, Guint codeToGIDLen, bool substitute);
 };
 
 //------------------------------------------------------------------------
@@ -87,17 +88,16 @@ class CairoType3Font : public CairoFont {
 public:
   static CairoType3Font *create(GfxFont *gfxFont, PDFDoc *doc,
 				CairoFontEngine *fontEngine,
-				GBool printing, XRef *xref);
+				bool printing, XRef *xref);
   ~CairoType3Font();
 
-  GBool matches(Ref &other, GBool printing) override;
+  bool matches(Ref &other, bool printing) override;
 
 private:
-  CairoType3Font(Ref ref, PDFDoc *doc,
+  CairoType3Font(Ref ref,
 		 cairo_font_face_t *cairo_font_face,
 		 int *codeToGID, Guint codeToGIDLen,
-		 GBool printing, XRef *xref);
-  PDFDoc *doc;
+		 bool printing, XRef *xref);
 };
 
 //------------------------------------------------------------------------
@@ -114,16 +114,16 @@ public:
   // Create a font engine.
   CairoFontEngine(FT_Library libA);
   ~CairoFontEngine();
+  CairoFontEngine(const CairoFontEngine &) = delete;
+  CairoFontEngine& operator=(const CairoFontEngine &other) = delete;
 
-  CairoFont *getFont(GfxFont *gfxFont, PDFDoc *doc, GBool printing, XRef *xref);
+  CairoFont *getFont(GfxFont *gfxFont, PDFDoc *doc, bool printing, XRef *xref);
 
 private:
   CairoFont *fontCache[cairoFontCacheSize];
   FT_Library lib;
-  GBool useCIDs;
-#if MULTITHREADED
-  GooMutex mutex;
-#endif
+  bool useCIDs;
+  mutable std::recursive_mutex mutex;
 };
 
 #endif
