@@ -14,13 +14,14 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2008 Julien Rebetez <julien@fhtagn.net>
-// Copyright (C) 2008, 2010, 2016, 2017 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2016-2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Matthias Franz <matthias@ktug.or.kr>
 // Copyright (C) 2009 David Benjamin <davidben@mit.edu>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2016 Alok Anand <alok4nand@gmail.com>
 // Copyright (C) 2016 Thomas Freitag <Thomas.Freitag@alfa.de>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -29,10 +30,6 @@
 
 #include <config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <cstdint>
 #include <string.h>
 #include "goo/gmem.h"
@@ -43,21 +40,21 @@
 static void rc4InitKey(Guchar *key, int keyLen, Guchar *state);
 static Guchar rc4DecryptByte(Guchar *state, Guchar *x, Guchar *y, Guchar c);
 
-static GBool aesReadBlock(Stream  *str, Guchar *in, GBool addPadding);
+static bool aesReadBlock(Stream  *str, Guchar *in, bool addPadding);
 
-static void aesKeyExpansion(DecryptAESState *s, Guchar *objKey, int objKeyLen, GBool decrypt);
+static void aesKeyExpansion(DecryptAESState *s, Guchar *objKey, int objKeyLen, bool decrypt);
 static void aesEncryptBlock(DecryptAESState *s, Guchar *in);
-static void aesDecryptBlock(DecryptAESState *s, Guchar *in, GBool last);
+static void aesDecryptBlock(DecryptAESState *s, Guchar *in, bool last);
 
-static void aes256KeyExpansion(DecryptAES256State *s, Guchar *objKey, int objKeyLen, GBool decrypt);
+static void aes256KeyExpansion(DecryptAES256State *s, Guchar *objKey, int objKeyLen, bool decrypt);
 static void aes256EncryptBlock(DecryptAES256State *s, Guchar *in);
-static void aes256DecryptBlock(DecryptAES256State *s, Guchar *in, GBool last);
+static void aes256DecryptBlock(DecryptAES256State *s, Guchar *in, bool last);
 
 static void sha256(Guchar *msg, int msgLen, Guchar *hash);
 static void sha384(Guchar *msg, int msgLen, Guchar *hash);
 static void sha512(Guchar *msg, int msgLen, Guchar *hash);
 
-static void revision6Hash(GooString *inputPassword, Guchar *K, char *userKey);
+static void revision6Hash(const GooString *inputPassword, Guchar *K, const char *userKey);
 
 static const Guchar passwordPad[32] = {
   0x28, 0xbf, 0x4e, 0x5e, 0x4e, 0x75, 0x8a, 0x41,
@@ -70,13 +67,13 @@ static const Guchar passwordPad[32] = {
 // Decrypt
 //------------------------------------------------------------------------
 
-GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
-			   GooString *ownerKey, GooString *userKey,
-			   GooString *ownerEnc, GooString *userEnc,
-			   int permissions, GooString *fileID,
-			   GooString *ownerPassword, GooString *userPassword,
-			   Guchar *fileKey, GBool encryptMetadata,
-			   GBool *ownerPasswordOk) {
+bool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
+			   const GooString *ownerKey, const GooString *userKey,
+			   const GooString *ownerEnc, const GooString *userEnc,
+			   int permissions, const GooString *fileID,
+			   const GooString *ownerPassword, const GooString *userPassword,
+			   Guchar *fileKey, bool encryptMetadata,
+			   bool *ownerPasswordOk) {
   DecryptAES256State state;
   Guchar test[127 + 56], test2[32];
   GooString *userPassword2;
@@ -85,7 +82,7 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
   Guchar fx, fy;
   int len, i, j;
 
-  *ownerPasswordOk = gFalse;
+  *ownerPasswordOk = false;
 
   if (encRevision == 5 || encRevision == 6) {
 
@@ -115,18 +112,18 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
 	  //test contains the initial SHA-256 hash input K.
 	  revision6Hash(ownerPassword, test, userKey->getCString());
 	}
-	aes256KeyExpansion(&state, test, 32, gTrue);
+	aes256KeyExpansion(&state, test, 32, true);
 	for (i = 0; i < 16; ++i) {
 	  state.cbc[i] = 0;
 	}
-	aes256DecryptBlock(&state, (Guchar *)ownerEnc->getCString(), gFalse);
+	aes256DecryptBlock(&state, (Guchar *)ownerEnc->getCString(), false);
 	memcpy(fileKey, state.buf, 16);
 	aes256DecryptBlock(&state, (Guchar *)ownerEnc->getCString() + 16,
-			   gFalse);
+			   false);
 	memcpy(fileKey + 16, state.buf, 16);
 
-	*ownerPasswordOk = gTrue;
-	return gTrue;
+	*ownerPasswordOk = true;
+	return true;
       }
     }
 
@@ -143,7 +140,7 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
       if(encRevision == 6) {
 	// test contains the initial SHA-256 hash input K.
 	// user key is not used in checking user password.
-	revision6Hash(userPassword, test, NULL);
+	revision6Hash(userPassword, test, nullptr);
       }
       if (!memcmp(test, userKey->getCString(), 32)) {
 
@@ -154,23 +151,23 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
 	if(encRevision == 6) {
 	  //test contains the initial SHA-256 hash input K.
 	  //user key is not used in computing intermediate user key.
-	  revision6Hash(userPassword, test, NULL);
+	  revision6Hash(userPassword, test, nullptr);
 	}
-	aes256KeyExpansion(&state, test, 32, gTrue);
+	aes256KeyExpansion(&state, test, 32, true);
 	for (i = 0; i < 16; ++i) {
 	  state.cbc[i] = 0;
 	}
-	aes256DecryptBlock(&state, (Guchar *)userEnc->getCString(), gFalse);
+	aes256DecryptBlock(&state, (Guchar *)userEnc->getCString(), false);
 	memcpy(fileKey, state.buf, 16);
 	aes256DecryptBlock(&state, (Guchar *)userEnc->getCString() + 16,
-			   gFalse);
+			   false);
 	memcpy(fileKey + 16, state.buf, 16);
 
-	return gTrue;
+	return true;
       }
     }
 
-    return gFalse;
+    return false;
   } else {
 
     // try using the supplied owner password to generate the user password
@@ -211,9 +208,9 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
       if (makeFileKey2(encVersion, encRevision, keyLength, ownerKey, userKey,
 		       permissions, fileID, userPassword2, fileKey,
 		       encryptMetadata)) {
-	*ownerPasswordOk = gTrue;
+	*ownerPasswordOk = true;
 	delete userPassword2;
-	return gTrue;
+	return true;
       }
       delete userPassword2;
     }
@@ -225,18 +222,18 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
   }
 }
 
-GBool Decrypt::makeFileKey2(int encVersion, int encRevision, int keyLength,
-			    GooString *ownerKey, GooString *userKey,
-			    int permissions, GooString *fileID,
-			    GooString *userPassword, Guchar *fileKey,
-			    GBool encryptMetadata) {
+bool Decrypt::makeFileKey2(int encVersion, int encRevision, int keyLength,
+			    const GooString *ownerKey, const GooString *userKey,
+			    int permissions, const GooString *fileID,
+			    const GooString *userPassword, Guchar *fileKey,
+			    bool encryptMetadata) {
   Guchar *buf;
   Guchar test[32];
   Guchar fState[256];
   Guchar tmpKey[16];
   Guchar fx, fy;
   int len, i, j;
-  GBool ok;
+  bool ok;
 
   // generate file key
   buf = (Guchar *)gmalloc(72 + fileID->getLength());
@@ -296,7 +293,7 @@ GBool Decrypt::makeFileKey2(int encVersion, int encRevision, int keyLength,
     md5(buf, 32 + fileID->getLength(), buf);
     ok = memcmp(test, buf, 16) == 0;
   } else {
-    ok = gFalse;
+    ok = false;
   }
 
   gfree(buf);
@@ -307,26 +304,30 @@ GBool Decrypt::makeFileKey2(int encVersion, int encRevision, int keyLength,
 // BaseCryptStream
 //------------------------------------------------------------------------
 
-BaseCryptStream::BaseCryptStream(Stream *strA, Guchar *fileKey, CryptAlgorithm algoA,
+BaseCryptStream::BaseCryptStream(Stream *strA, const Guchar *fileKey, CryptAlgorithm algoA,
 				 int keyLength, int objNum, int objGen):
   FilterStream(strA)
 {
-  int i;
-
   algo = algoA;
 
   // construct object key
-  for (i = 0; i < keyLength; ++i) {
+  for (int i = 0; i < keyLength; ++i) {
     objKey[i] = fileKey[i];
   }
+  for (std::size_t i = keyLength; i < sizeof(objKey); ++i) {
+    objKey[i] = 0;
+  }
+
   switch (algo) {
   case cryptRC4:
-    objKey[keyLength] = objNum & 0xff;
-    objKey[keyLength + 1] = (objNum >> 8) & 0xff;
-    objKey[keyLength + 2] = (objNum >> 16) & 0xff;
-    objKey[keyLength + 3] = objGen & 0xff;
-    objKey[keyLength + 4] = (objGen >> 8) & 0xff;
-    md5(objKey, keyLength + 5, objKey);
+    if (likely(keyLength < static_cast<int>(sizeof(objKey) - 4))) {
+      objKey[keyLength] = objNum & 0xff;
+      objKey[keyLength + 1] = (objNum >> 8) & 0xff;
+      objKey[keyLength + 2] = (objNum >> 16) & 0xff;
+      objKey[keyLength + 3] = objGen & 0xff;
+      objKey[keyLength + 4] = (objGen >> 8) & 0xff;
+      md5(objKey, keyLength + 5, objKey);
+    }
     if ((objKeyLength = keyLength + 5) > 16) {
       objKeyLength = 16;
     }
@@ -354,7 +355,7 @@ BaseCryptStream::BaseCryptStream(Stream *strA, Guchar *fileKey, CryptAlgorithm a
   }
 
   charactersRead = 0;
-  autoDelete = gTrue;
+  autoDelete = true;
 }
 
 BaseCryptStream::~BaseCryptStream() {
@@ -383,11 +384,11 @@ int BaseCryptStream::getChar() {
   return c;
 }
 
-GBool BaseCryptStream::isBinary(GBool last) {
+bool BaseCryptStream::isBinary(bool last) {
   return str->isBinary(last);
 }
 
-void BaseCryptStream::setAutoDelete(GBool val) {
+void BaseCryptStream::setAutoDelete(bool val) {
   autoDelete = val;
 }
 
@@ -395,7 +396,7 @@ void BaseCryptStream::setAutoDelete(GBool val) {
 // EncryptStream
 //------------------------------------------------------------------------
 
-EncryptStream::EncryptStream(Stream *strA, Guchar *fileKey, CryptAlgorithm algoA,
+EncryptStream::EncryptStream(Stream *strA, const Guchar *fileKey, CryptAlgorithm algoA,
 			     int keyLength, int objNum, int objGen):
   BaseCryptStream(strA, fileKey, algoA, keyLength, objNum, objGen)
 {
@@ -424,16 +425,16 @@ void EncryptStream::reset() {
     rc4InitKey(objKey, objKeyLength, state.rc4.state);
     break;
   case cryptAES:
-    aesKeyExpansion(&state.aes, objKey, objKeyLength, gFalse);
+    aesKeyExpansion(&state.aes, objKey, objKeyLength, false);
     memcpy(state.aes.buf, state.aes.cbc, 16); // Copy CBC IV to buf
     state.aes.bufIdx = 0;
-    state.aes.paddingReached = gFalse;
+    state.aes.paddingReached = false;
     break;
   case cryptAES256:
-    aes256KeyExpansion(&state.aes256, objKey, objKeyLength, gFalse);
+    aes256KeyExpansion(&state.aes256, objKey, objKeyLength, false);
     memcpy(state.aes256.buf, state.aes256.cbc, 16); // Copy CBC IV to buf
     state.aes256.bufIdx = 0;
-    state.aes256.paddingReached = gFalse;
+    state.aes256.paddingReached = false;
     break;
   case cryptNone:
     break;
@@ -457,7 +458,7 @@ int EncryptStream::lookChar() {
     break;
   case cryptAES:
     if (state.aes.bufIdx == 16 && !state.aes.paddingReached) {
-      state.aes.paddingReached = !aesReadBlock(str, in, gTrue);
+      state.aes.paddingReached = !aesReadBlock(str, in, true);
       aesEncryptBlock(&state.aes, in);
     }
     if (state.aes.bufIdx == 16) {
@@ -468,7 +469,7 @@ int EncryptStream::lookChar() {
     break;
   case cryptAES256:
     if (state.aes256.bufIdx == 16 && !state.aes256.paddingReached) {
-      state.aes256.paddingReached = !aesReadBlock(str, in, gTrue);
+      state.aes256.paddingReached = !aesReadBlock(str, in, true);
       aes256EncryptBlock(&state.aes256, in);
     }
     if (state.aes256.bufIdx == 16) {
@@ -487,7 +488,7 @@ int EncryptStream::lookChar() {
 // DecryptStream
 //------------------------------------------------------------------------
 
-DecryptStream::DecryptStream(Stream *strA, Guchar *fileKey, CryptAlgorithm algoA,
+DecryptStream::DecryptStream(Stream *strA, const Guchar *fileKey, CryptAlgorithm algoA,
 			     int keyLength, int objNum, int objGen):
   BaseCryptStream(strA, fileKey, algoA, keyLength, objNum, objGen)
 {
@@ -506,14 +507,14 @@ void DecryptStream::reset() {
     rc4InitKey(objKey, objKeyLength, state.rc4.state);
     break;
   case cryptAES:
-    aesKeyExpansion(&state.aes, objKey, objKeyLength, gTrue);
+    aesKeyExpansion(&state.aes, objKey, objKeyLength, true);
     for (i = 0; i < 16; ++i) {
       state.aes.cbc[i] = str->getChar();
     }
     state.aes.bufIdx = 16;
     break;
   case cryptAES256:
-    aes256KeyExpansion(&state.aes256, objKey, objKeyLength, gTrue);
+    aes256KeyExpansion(&state.aes256, objKey, objKeyLength, true);
     for (i = 0; i < 16; ++i) {
       state.aes256.cbc[i] = str->getChar();
     }
@@ -540,7 +541,7 @@ int DecryptStream::lookChar() {
     break;
   case cryptAES:
     if (state.aes.bufIdx == 16) {
-      if (aesReadBlock(str, in, gFalse)) {
+      if (aesReadBlock(str, in, false)) {
         aesDecryptBlock(&state.aes, in, str->lookChar() == EOF);
       }
     }
@@ -552,7 +553,7 @@ int DecryptStream::lookChar() {
     break;
   case cryptAES256:
     if (state.aes256.bufIdx == 16) {
-      if (aesReadBlock(str, in, gFalse)) {
+      if (aesReadBlock(str, in, false)) {
         aes256DecryptBlock(&state.aes256, in, str->lookChar() == EOF);
       }
     }
@@ -609,8 +610,8 @@ static Guchar rc4DecryptByte(Guchar *state, Guchar *x, Guchar *y, Guchar c) {
 // AES decryption
 //------------------------------------------------------------------------
 
-// Returns gFalse if EOF was reached, gTrue otherwise
-static GBool aesReadBlock(Stream *str, Guchar *in, GBool addPadding)
+// Returns false if EOF was reached, true otherwise
+static bool aesReadBlock(Stream *str, Guchar *in, bool addPadding)
 {
   int c, i;
 
@@ -623,7 +624,7 @@ static GBool aesReadBlock(Stream *str, Guchar *in, GBool addPadding)
   }
 
   if (i == 16) {
-    return gTrue;
+    return true;
   } else {
     if (addPadding) {
       c = 16 - i;
@@ -631,7 +632,7 @@ static GBool aesReadBlock(Stream *str, Guchar *in, GBool addPadding)
         in[i++] = (Guchar)c;
       }
     }
-    return gFalse;
+    return false;
   }
 }
 
@@ -871,7 +872,7 @@ static inline void addRoundKey(Guchar *state, Guint *w) {
 }
 
 static void aesKeyExpansion(DecryptAESState *s,
-			    Guchar *objKey, int /*objKeyLen*/, GBool decrypt) {
+			    Guchar *objKey, int /*objKeyLen*/, bool decrypt) {
   Guint temp;
   int i, round;
 
@@ -934,7 +935,7 @@ static void aesEncryptBlock(DecryptAESState *s, Guchar *in) {
   s->bufIdx = 0;
 }
 
-static void aesDecryptBlock(DecryptAESState *s, Guchar *in, GBool last) {
+static void aesDecryptBlock(DecryptAESState *s, Guchar *in, bool last) {
   int c, round, n, i;
 
   // initial state
@@ -993,7 +994,7 @@ static void aesDecryptBlock(DecryptAESState *s, Guchar *in, GBool last) {
 //------------------------------------------------------------------------
 
 static void aes256KeyExpansion(DecryptAES256State *s,
-			       Guchar *objKey, int objKeyLen, GBool decrypt) {
+			       Guchar *objKey, int objKeyLen, bool decrypt) {
   Guint temp;
   int i, round;
 
@@ -1058,7 +1059,7 @@ static void aes256EncryptBlock(DecryptAES256State *s, Guchar *in) {
   s->bufIdx = 0;
 }
 
-static void aes256DecryptBlock(DecryptAES256State *s, Guchar *in, GBool last) {
+static void aes256DecryptBlock(DecryptAES256State *s, Guchar *in, bool last) {
   int c, round, n, i;
 
   // initial state
@@ -1147,8 +1148,8 @@ static inline Gulong md5Round4(Gulong a, Gulong b, Gulong c, Gulong d,
   return b + rotateLeft((a + (c ^ (b | ~d)) + Xk + Ti), s);
 }
 
-void md5(Guchar *msg, int msgLen, Guchar *digest) {
-  Gulong x[16];
+void md5(const Guchar *msg, int msgLen, Guchar *digest) {
+  Gulong x[16] = {};
   Gulong a, b, c, d, aa, bb, cc, dd;
   int n64;
   int i, j, k;
@@ -1454,7 +1455,7 @@ static void sha256(Guchar *msg, int msgLen, Guchar *hash) {
 // SHA-512 hash (see FIPS 180-4)
 //------------------------------------------------------------------------
 // SHA 384 and SHA 512 use the same sequence of eighty constant 64 bit words.
-static const uint64_t K[80] = {
+static const uint64_t shaK[80] = {
   0x428a2f98d728ae22ull, 0x7137449123ef65cdull, 0xb5c0fbcfec4d3b2full, 0xe9b5dba58189dbbcull, 0x3956c25bf348b538ull,
   0x59f111f1b605d019ull, 0x923f82a4af194f9bull, 0xab1c5ed5da6d8118ull, 0xd807aa98a3030242ull, 0x12835b0145706fbeull,
   0x243185be4ee4b28cull, 0x550c7dc3d5ffb4e2ull, 0x72be5d74f27b896full, 0x80deb1fe3b1696b1ull, 0x9bdc06a725c71235ull,
@@ -1476,9 +1477,6 @@ static const uint64_t K[80] = {
 static inline uint64_t rotr(uint64_t x, uint64_t n) {
   return (x >> n) | (x << (64 - n));
 }
-static inline uint64_t rotl(uint64_t x, uint64_t n){
-  return (x << n) | (x >> (64 - n));
-}
 static inline uint64_t sha512Ch(uint64_t x, uint64_t y, uint64_t z) {
   return (x & y) ^ (~x & z);
 }
@@ -1531,7 +1529,7 @@ static void sha512HashBlock(Guchar *blk, uint64_t *H) {
 
   // 3.
   for (t = 0; t < 80; ++t) {
-    T1 = h + sha512Sigma1(e) + sha512Ch(e,f,g) + K[t] + W[t];
+    T1 = h + sha512Sigma1(e) + sha512Ch(e,f,g) + shaK[t] + W[t];
     T2 = sha512Sigma0(a) + sha512Maj(a,b,c);
     h = g;
     g = f;
@@ -1698,7 +1696,7 @@ static void sha384(Guchar *msg, int msgLen, Guchar *hash) {
 // Section 7.6.3.3 (Encryption Key algorithm) of ISO/DIS 32000-2
 // Algorithm 2.B:Computing a hash (for revision 6).
 //------------------------------------------------------------------------
-static void revision6Hash(GooString *inputPassword, Guchar *K, char *userKey) {
+static void revision6Hash(const GooString *inputPassword, Guchar *K, const char *userKey) {
   Guchar K1[64*(127+64+48)];
   Guchar  E[64*(127+64+48)];
   DecryptAESState state;
@@ -1730,8 +1728,8 @@ static void revision6Hash(GooString *inputPassword, Guchar *K, char *userKey) {
     memcpy(state.cbc,K + 16,16);
     memcpy(state.buf, state.cbc, 16); // Copy CBC IV to buf
     state.bufIdx = 0;
-    state.paddingReached = gFalse;
-    aesKeyExpansion(&state,aesKey,16,gFalse);
+    state.paddingReached = false;
+    aesKeyExpansion(&state,aesKey,16,false);
 
     for(int i = 0; i < (4 * sequenceLength); i++) {
       aesEncryptBlock(&state,K1 + (16 * i));
