@@ -6,7 +6,7 @@
    // Copyright (C) 2012 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
    // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
    // Copyright (C) 2012 Mark Brand <mabrand@mabrand.nl>
-   // Copyright (C) 2013 Adam Reichold <adamreichold@myopera.com>
+   // Copyright (C) 2013, 2018 Adam Reichold <adamreichold@myopera.com>
    // Copyright (C) 2013 Dmytro Morgun <lztoad@gmail.com>
    // Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
    // Copyright (C) 2017, 2018 Albert Astals Cid <aacid@kde.org>
@@ -21,10 +21,6 @@ description for all fonts available in Windows. That's how MuPDF works.
 #include <config.h>
 #endif
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <windows.h>
 #if !(_WIN32_IE >= 0x0500)
 #error "_WIN32_IE must be defined >= 0x0500 for SHGFP_TYPE_CURRENT from shlobj.h"
@@ -38,7 +34,6 @@ description for all fonts available in Windows. That's how MuPDF works.
 #include "goo/gmem.h"
 #include "goo/GooString.h"
 #include "goo/GooList.h"
-#include "goo/GooHash.h"
 #include "goo/gfile.h"
 #include "Error.h"
 #include "NameToCharCode.h"
@@ -55,22 +50,6 @@ description for all fonts available in Windows. That's how MuPDF works.
 #include "Lexer.h"
 #include "Parser.h"
 
-#ifdef MULTITHREADED
-#  define lockGlobalParams            gLockMutex(&mutex)
-#  define lockUnicodeMapCache         gLockMutex(&unicodeMapCacheMutex)
-#  define lockCMapCache               gLockMutex(&cMapCacheMutex)
-#  define unlockGlobalParams          gUnlockMutex(&mutex)
-#  define unlockUnicodeMapCache       gUnlockMutex(&unicodeMapCacheMutex)
-#  define unlockCMapCache             gUnlockMutex(&cMapCacheMutex)
-#else
-#  define lockGlobalParams
-#  define lockUnicodeMapCache
-#  define lockCMapCache
-#  define unlockGlobalParams
-#  define unlockUnicodeMapCache
-#  define unlockCMapCache
-#endif
-
 #define DEFAULT_SUBSTITUTE_FONT "Helvetica"
 #define DEFAULT_CID_FONT_AC1_MSWIN "MingLiU"   /* Adobe-CNS1 for Taiwan, HongKong */
 #define DEFAULT_CID_FONT_AG1_MSWIN "SimSun"    /* Adobe-GB1 for PRC, Singapore */
@@ -83,98 +62,98 @@ static const struct {
     const char *name;
     const char *t1FileName;
     const char *ttFileName;
-    GBool warnIfMissing;
+    bool warnIfMissing;
 } displayFontTab[] = {
-    {"Courier",               "n022003l.pfb", "cour.ttf", gTrue},
-    {"Courier-Bold",          "n022004l.pfb", "courbd.ttf", gTrue},
-    {"Courier-BoldOblique",   "n022024l.pfb", "courbi.ttf", gTrue},
-    {"Courier-Oblique",       "n022023l.pfb", "couri.ttf", gTrue},
-    {"Helvetica",             "n019003l.pfb", "arial.ttf", gTrue},
-    {"Helvetica-Bold",        "n019004l.pfb", "arialbd.ttf", gTrue},
-    {"Helvetica-BoldOblique", "n019024l.pfb", "arialbi.ttf", gTrue},
-    {"Helvetica-Oblique",     "n019023l.pfb", "ariali.ttf", gTrue},
+    {"Courier",               "n022003l.pfb", "cour.ttf", true},
+    {"Courier-Bold",          "n022004l.pfb", "courbd.ttf", true},
+    {"Courier-BoldOblique",   "n022024l.pfb", "courbi.ttf", true},
+    {"Courier-Oblique",       "n022023l.pfb", "couri.ttf", true},
+    {"Helvetica",             "n019003l.pfb", "arial.ttf", true},
+    {"Helvetica-Bold",        "n019004l.pfb", "arialbd.ttf", true},
+    {"Helvetica-BoldOblique", "n019024l.pfb", "arialbi.ttf", true},
+    {"Helvetica-Oblique",     "n019023l.pfb", "ariali.ttf", true},
     // TODO: not sure if "symbol.ttf" is right
-    {"Symbol",                "s050000l.pfb", "symbol.ttf", gTrue},
-    {"Times-Bold",            "n021004l.pfb", "timesbd.ttf", gTrue},
-    {"Times-BoldItalic",      "n021024l.pfb", "timesbi.ttf", gTrue},
-    {"Times-Italic",          "n021023l.pfb", "timesi.ttf", gTrue},
-    {"Times-Roman",           "n021003l.pfb", "times.ttf", gTrue},
+    {"Symbol",                "s050000l.pfb", "symbol.ttf", true},
+    {"Times-Bold",            "n021004l.pfb", "timesbd.ttf", true},
+    {"Times-BoldItalic",      "n021024l.pfb", "timesbi.ttf", true},
+    {"Times-Italic",          "n021023l.pfb", "timesi.ttf", true},
+    {"Times-Roman",           "n021003l.pfb", "times.ttf", true},
     // TODO: not sure if "wingding.ttf" is right
-    {"ZapfDingbats",          "d050000l.pfb", "wingding.ttf", gTrue},
+    {"ZapfDingbats",          "d050000l.pfb", "wingding.ttf", true},
 
     // those seem to be frequently accessed by PDF files and I kind of guess
     // which font file do the refer to
-    {"Palatino", nullptr, "pala.ttf", gTrue},
-    {"Palatino-Roman", nullptr, "pala.ttf", gTrue},
-    {"Palatino-Bold", nullptr, "palab.ttf", gTrue},
-    {"Palatino-Italic", nullptr, "palai.ttf", gTrue},
-    {"Palatino,Italic", nullptr, "palai.ttf", gTrue},
-    {"Palatino-BoldItalic", nullptr, "palabi.ttf", gTrue},
+    {"Palatino", nullptr, "pala.ttf", true},
+    {"Palatino-Roman", nullptr, "pala.ttf", true},
+    {"Palatino-Bold", nullptr, "palab.ttf", true},
+    {"Palatino-Italic", nullptr, "palai.ttf", true},
+    {"Palatino,Italic", nullptr, "palai.ttf", true},
+    {"Palatino-BoldItalic", nullptr, "palabi.ttf", true},
 
-    {"ArialBlack",        nullptr, "arialbd.ttf", gTrue},
+    {"ArialBlack",        nullptr, "arialbd.ttf", true},
 
-    {"ArialNarrow", nullptr, "arialn.ttf", gTrue},
-    {"ArialNarrow,Bold", nullptr, "arialnb.ttf", gTrue},
-    {"ArialNarrow,Italic", nullptr, "arialni.ttf", gTrue},
-    {"ArialNarrow,BoldItalic", nullptr, "arialnbi.ttf", gTrue},
-    {"ArialNarrow-Bold", nullptr, "arialnb.ttf", gTrue},
-    {"ArialNarrow-Italic", nullptr, "arialni.ttf", gTrue},
-    {"ArialNarrow-BoldItalic", nullptr, "arialnbi.ttf", gTrue},
+    {"ArialNarrow", nullptr, "arialn.ttf", true},
+    {"ArialNarrow,Bold", nullptr, "arialnb.ttf", true},
+    {"ArialNarrow,Italic", nullptr, "arialni.ttf", true},
+    {"ArialNarrow,BoldItalic", nullptr, "arialnbi.ttf", true},
+    {"ArialNarrow-Bold", nullptr, "arialnb.ttf", true},
+    {"ArialNarrow-Italic", nullptr, "arialni.ttf", true},
+    {"ArialNarrow-BoldItalic", nullptr, "arialnbi.ttf", true},
 
-    {"HelveticaNarrow", nullptr, "arialn.ttf", gTrue},
-    {"HelveticaNarrow,Bold", nullptr, "arialnb.ttf", gTrue},
-    {"HelveticaNarrow,Italic", nullptr, "arialni.ttf", gTrue},
-    {"HelveticaNarrow,BoldItalic", nullptr, "arialnbi.ttf", gTrue},
-    {"HelveticaNarrow-Bold", nullptr, "arialnb.ttf", gTrue},
-    {"HelveticaNarrow-Italic", nullptr, "arialni.ttf", gTrue},
-    {"HelveticaNarrow-BoldItalic", nullptr, "arialnbi.ttf", gTrue},
+    {"HelveticaNarrow", nullptr, "arialn.ttf", true},
+    {"HelveticaNarrow,Bold", nullptr, "arialnb.ttf", true},
+    {"HelveticaNarrow,Italic", nullptr, "arialni.ttf", true},
+    {"HelveticaNarrow,BoldItalic", nullptr, "arialnbi.ttf", true},
+    {"HelveticaNarrow-Bold", nullptr, "arialnb.ttf", true},
+    {"HelveticaNarrow-Italic", nullptr, "arialni.ttf", true},
+    {"HelveticaNarrow-BoldItalic", nullptr, "arialnbi.ttf", true},
 
-    {"BookAntiqua", nullptr, "bkant.ttf", gTrue},
-    {"BookAntiqua,Bold", nullptr, "bkant.ttf", gTrue},
-    {"BookAntiqua,Italic", nullptr, "bkant.ttf", gTrue},
-    {"BookAntiqua,BoldItalic", nullptr, "bkant.ttf", gTrue},
-    {"BookAntiqua-Bold", nullptr, "bkant.ttf", gTrue},
-    {"BookAntiqua-Italic", nullptr, "bkant.ttf", gTrue},
-    {"BookAntiqua-BoldItalic", nullptr, "bkant.ttf", gTrue},
+    {"BookAntiqua", nullptr, "bkant.ttf", true},
+    {"BookAntiqua,Bold", nullptr, "bkant.ttf", true},
+    {"BookAntiqua,Italic", nullptr, "bkant.ttf", true},
+    {"BookAntiqua,BoldItalic", nullptr, "bkant.ttf", true},
+    {"BookAntiqua-Bold", nullptr, "bkant.ttf", true},
+    {"BookAntiqua-Italic", nullptr, "bkant.ttf", true},
+    {"BookAntiqua-BoldItalic", nullptr, "bkant.ttf", true},
 
-    {"Verdana", nullptr, "verdana.ttf", gTrue},
-    {"Verdana,Bold", nullptr, "verdanab.ttf", gTrue},
-    {"Verdana,Italic", nullptr, "verdanai.ttf", gTrue},
-    {"Verdana,BoldItalic", nullptr, "verdanaz.ttf", gTrue},
-    {"Verdana-Bold", nullptr, "verdanab.ttf", gTrue},
-    {"Verdana-Italic", nullptr, "verdanai.ttf", gTrue},
-    {"Verdana-BoldItalic", nullptr, "verdanaz.ttf", gTrue},
+    {"Verdana", nullptr, "verdana.ttf", true},
+    {"Verdana,Bold", nullptr, "verdanab.ttf", true},
+    {"Verdana,Italic", nullptr, "verdanai.ttf", true},
+    {"Verdana,BoldItalic", nullptr, "verdanaz.ttf", true},
+    {"Verdana-Bold", nullptr, "verdanab.ttf", true},
+    {"Verdana-Italic", nullptr, "verdanai.ttf", true},
+    {"Verdana-BoldItalic", nullptr, "verdanaz.ttf", true},
 
-    {"Tahoma", nullptr, "tahoma.ttf", gTrue},
-    {"Tahoma,Bold", nullptr, "tahomabd.ttf", gTrue},
-    {"Tahoma,Italic", nullptr, "tahoma.ttf", gTrue},
-    {"Tahoma,BoldItalic", nullptr, "tahomabd.ttf", gTrue},
-    {"Tahoma-Bold", nullptr, "tahomabd.ttf", gTrue},
-    {"Tahoma-Italic", nullptr, "tahoma.ttf", gTrue},
-    {"Tahoma-BoldItalic", nullptr, "tahomabd.ttf", gTrue},
+    {"Tahoma", nullptr, "tahoma.ttf", true},
+    {"Tahoma,Bold", nullptr, "tahomabd.ttf", true},
+    {"Tahoma,Italic", nullptr, "tahoma.ttf", true},
+    {"Tahoma,BoldItalic", nullptr, "tahomabd.ttf", true},
+    {"Tahoma-Bold", nullptr, "tahomabd.ttf", true},
+    {"Tahoma-Italic", nullptr, "tahoma.ttf", true},
+    {"Tahoma-BoldItalic", nullptr, "tahomabd.ttf", true},
 
-    {"CCRIKH+Verdana", nullptr, "verdana.ttf", gTrue},
-    {"CCRIKH+Verdana,Bold", nullptr, "verdanab.ttf", gTrue},
-    {"CCRIKH+Verdana,Italic", nullptr, "verdanai.ttf", gTrue},
-    {"CCRIKH+Verdana,BoldItalic", nullptr, "verdanaz.ttf", gTrue},
-    {"CCRIKH+Verdana-Bold", nullptr, "verdanab.ttf", gTrue},
-    {"CCRIKH+Verdana-Italic", nullptr, "verdanai.ttf", gTrue},
-    {"CCRIKH+Verdana-BoldItalic", nullptr, "verdanaz.ttf", gTrue},
+    {"CCRIKH+Verdana", nullptr, "verdana.ttf", true},
+    {"CCRIKH+Verdana,Bold", nullptr, "verdanab.ttf", true},
+    {"CCRIKH+Verdana,Italic", nullptr, "verdanai.ttf", true},
+    {"CCRIKH+Verdana,BoldItalic", nullptr, "verdanaz.ttf", true},
+    {"CCRIKH+Verdana-Bold", nullptr, "verdanab.ttf", true},
+    {"CCRIKH+Verdana-Italic", nullptr, "verdanai.ttf", true},
+    {"CCRIKH+Verdana-BoldItalic", nullptr, "verdanaz.ttf", true},
 
-    {"Georgia", nullptr, "georgia.ttf", gTrue},
-    {"Georgia,Bold", nullptr, "georgiab.ttf", gTrue},
-    {"Georgia,Italic", nullptr, "georgiai.ttf", gTrue},
-    {"Georgia,BoldItalic", nullptr, "georgiaz.ttf", gTrue},
-    {"Georgia-Bold", nullptr, "georgiab.ttf", gTrue},
-    {"Georgia-Italic", nullptr, "georgiai.ttf", gTrue},
-    {"Georgia-BoldItalic", nullptr, "georgiaz.ttf", gTrue},
+    {"Georgia", nullptr, "georgia.ttf", true},
+    {"Georgia,Bold", nullptr, "georgiab.ttf", true},
+    {"Georgia,Italic", nullptr, "georgiai.ttf", true},
+    {"Georgia,BoldItalic", nullptr, "georgiaz.ttf", true},
+    {"Georgia-Bold", nullptr, "georgiab.ttf", true},
+    {"Georgia-Italic", nullptr, "georgiai.ttf", true},
+    {"Georgia-BoldItalic", nullptr, "georgiaz.ttf", true},
 
     // fallback for Adobe CID fonts:
-    {"MingLiU", nullptr, "mingliu.ttf", gFalse},
-    {"SimSun", nullptr, "simsun.ttf", gFalse},
-    {"MS-Mincho", nullptr, "msmincho.ttf", gFalse},
-    {"Batang", nullptr, "batang.ttf", gFalse},
-    {"ArialUnicode", nullptr, "arialuni.ttf", gTrue},
+    {"MingLiU", nullptr, "mingliu.ttf", false},
+    {"SimSun", nullptr, "simsun.ttf", false},
+    {"MS-Mincho", nullptr, "msmincho.ttf", false},
+    {"Batang", nullptr, "batang.ttf", false},
+    {"ArialUnicode", nullptr, "arialuni.ttf", true},
     { }
 };
 
@@ -298,7 +277,7 @@ void SysFontList::scanWindowsFonts(GooString *winFontDir) {
 	    } else {
 	      p1 = p0 + strlen(p0);
 	    }
-	    fonts->append(makeWindowsFont(p0, fontNum,
+	    fonts->push_back(makeWindowsFont(p0, fontNum,
 					  fontPath->getCString()));
 	    p0 = p1;
 	    ++fontNum;
@@ -312,10 +291,10 @@ void SysFontList::scanWindowsFonts(GooString *winFontDir) {
   }
 }
 
-SysFontInfo *SysFontList::makeWindowsFont(char *name, int fontNum,
-					  char *path) {
+SysFontInfo *SysFontList::makeWindowsFont(const char *name, int fontNum,
+					  const char *path) {
   int n;
-  GBool bold, italic, oblique, fixedWidth;
+  bool bold, italic, oblique, fixedWidth;
   GooString *s;
   char c;
   int i;
@@ -323,7 +302,7 @@ SysFontInfo *SysFontList::makeWindowsFont(char *name, int fontNum,
   GooString substituteName;
 
   n = strlen(name);
-  bold = italic = oblique = fixedWidth = gFalse;
+  bold = italic = oblique = fixedWidth = false;
 
   // remove trailing ' (TrueType)'
   if (n > 11 && !strncmp(name + n - 11, " (TrueType)", 11)) {
@@ -338,19 +317,19 @@ SysFontInfo *SysFontList::makeWindowsFont(char *name, int fontNum,
   // remove trailing ' Italic'
   if (n > 7 && !strncmp(name + n - 7, " Italic", 7)) {
     n -= 7;
-    italic = gTrue;
+    italic = true;
   }
 
   // remove trailing ' Oblique'
   if (n > 7 && !strncmp(name + n - 8, " Oblique", 8)) {
     n -= 8;
-    oblique = gTrue;
+    oblique = true;
   }
 
   // remove trailing ' Bold'
   if (n > 5 && !strncmp(name + n - 5, " Bold", 5)) {
     n -= 5;
-    bold = gTrue;
+    bold = true;
   }
 
   // remove trailing ' Regular'
@@ -364,9 +343,9 @@ SysFontInfo *SysFontList::makeWindowsFont(char *name, int fontNum,
        strstr(name, "Fixed")   ||
       (strstr(name, "Mono") && !strstr(name, "Monotype")) ||
        strstr(name, "Typewriter") )
-    fixedWidth = gTrue;
+    fixedWidth = true;
   else
-    fixedWidth = gFalse;
+    fixedWidth = false;
 
 
   //----- normalize the font name
@@ -423,10 +402,11 @@ void GlobalParams::setupBaseFonts(char * dir)
     GetWindowsFontDir(winFontDir, sizeof(winFontDir));
 
     for (int i = 0; displayFontTab[i].name; ++i) {
-        GooString  *fontName = new GooString(displayFontTab[i].name);
-        if (fontFiles->lookup(fontName))
+        if (fontFiles.count(displayFontTab[i].name) > 0)
             continue;
 
+        GooString  *fontName = new GooString(displayFontTab[i].name);
+
         if (dir) {
             GooString *fontPath = appendToPath(new GooString(dir), displayFontTab[i].t1FileName);
             if (FileExists(fontPath->getCString()) ||
@@ -467,8 +447,8 @@ void GlobalParams::setupBaseFonts(char * dir)
       Parser *parser;
       parser = new Parser(nullptr,
 	      new Lexer(nullptr,
-	      new FileStream(file, 0, gFalse, file->size(), Object(objNull))),
-	      gTrue);
+	      new FileStream(file, 0, false, file->size(), Object(objNull))),
+	      true);
       Object obj1 = parser->getObj();
       while (!obj1.isEOF()) {
 	    Object obj2 = parser->getObj();
@@ -480,7 +460,7 @@ void GlobalParams::setupBaseFonts(char * dir)
 	          addFontFile(new GooString(obj1.getName()), obj3.getString()->copy());
 	      // Aliases
 	      } else if (obj2.isName()) {
-	        substFiles->add(new GooString(obj1.getName()), new GooString(obj2.getName()));
+                substFiles.emplace(obj1.getName(), obj2.getName());
 	      }
 	    }
 	    obj1 = parser->getObj();
@@ -497,8 +477,8 @@ void GlobalParams::setupBaseFonts(char * dir)
     }
 }
 
-static const char *findSubstituteName(GfxFont *font, GooHash *fontFiles,
-                                      GooHash *substFiles,
+static const char *findSubstituteName(GfxFont *font, const std::unordered_map<std::string, std::string>& fontFiles,
+                                      const std::unordered_map<std::string, std::string>& substFiles,
                                       const char *origName)
 {
     assert(origName);
@@ -515,16 +495,16 @@ static const char *findSubstituteName(GfxFont *font, GooHash *fontFiles,
       name2->del(n - 11, 11);
       n -= 11;
     }
-    GooString *substName = (GooString *)substFiles->lookup(name2);
-    if (substName != nullptr) {
+    const auto substFile = substFiles.find(name2->getCString());
+    if (substFile != substFiles.end()) {
       delete name2;
-      return substName->getCString();
+      return substFile->second.c_str();
     }
 
     /* TODO: try to at least guess bold/italic/bolditalic from the name */
     delete name2;
     if (font->isCIDFont()) {
-      GooString *collection = ((GfxCIDFont *)font)->getCollection();
+      const GooString *collection = ((GfxCIDFont *)font)->getCollection();
 
       const char* name3 = nullptr;
       if ( !collection->cmp("Adobe-CNS1") )
@@ -538,10 +518,10 @@ static const char *findSubstituteName(GfxFont *font, GooHash *fontFiles,
       else if ( !collection->cmp("Adobe-Korea1") )
         name3 = DEFAULT_CID_FONT_AK1_MSWIN;
 
-      if (name3 && fontFiles->lookup(name3))
+      if (name3 && fontFiles.count(name3) != 0)
         return name3;
 
-      if (fontFiles->lookup(DEFAULT_CID_FONT_MSWIN))
+      if (fontFiles.count(DEFAULT_CID_FONT_MSWIN) != 0)
         return DEFAULT_CID_FONT_MSWIN;
     } 
     return DEFAULT_SUBSTITUTE_FONT;
@@ -551,19 +531,19 @@ static const char *findSubstituteName(GfxFont *font, GooHash *fontFiles,
 GooString *GlobalParams::findSystemFontFile(GfxFont *font,
 					  SysFontType *type,
 					  int *fontNum, GooString *substituteFontName,
-                                          GooString *base14Name) {
+                                          const GooString *base14Name) {
   SysFontInfo *fi;
   GooString *path = nullptr;
   const GooString *fontName = font->getName();
   if (!fontName) return nullptr;
-  lockGlobalParams;
+  std::unique_lock<std::recursive_mutex> locker(mutex);
   setupBaseFonts(nullptr);
 
   // TODO: base14Name should be changed?
   // In the system using FontConfig, findSystemFontFile() uses
   // base14Name only for the creation of query pattern.
 
-  if ((fi = sysFonts->find(fontName, gFalse, gFalse))) {
+  if ((fi = sysFonts->find(fontName, false, false))) {
     path = fi->path->copy();
     *type = fi->type;
     *fontNum = fi->fontNum;
@@ -573,10 +553,10 @@ GooString *GlobalParams::findSystemFontFile(GfxFont *font,
     GooString *substFontName = new GooString(findSubstituteName(font, fontFiles,
                                                                 substFiles,
                                                                 fontName->getCString()));
-    GooString *path2 = nullptr;
     error(errSyntaxError, -1, "Couldn't find a font for '{0:t}', subst is '{1:t}'", fontName, substFontName);
-    if ((path2 = (GooString *)fontFiles->lookup(substFontName))) {
-      path = new GooString(path2);
+    const auto fontFile = fontFiles.find(substFontName->toStr());
+    if (fontFile != fontFiles.end()) {
+      path = new GooString(fontFile->second.c_str());
       if (substituteFontName)
 	substituteFontName->Set(path->getCString());
       if (!strcasecmp(path->getCString() + path->getLength() - 4, ".ttc")) {
@@ -587,6 +567,6 @@ GooString *GlobalParams::findSystemFontFile(GfxFont *font,
       *fontNum = 0;
     }
   }
-  unlockGlobalParams;
+
   return path;
 }
