@@ -15,6 +15,7 @@
 //
 // Copyright (C) 2009 David Benjamin <davidben@mit.edu>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2015 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -24,10 +25,6 @@
 #ifndef JBIG2STREAM_H
 #define JBIG2STREAM_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include "goo/gtypes.h"
 #include "Object.h"
 #include "Stream.h"
@@ -46,28 +43,30 @@ class JBIG2MMRDecoder;
 class JBIG2Stream: public FilterStream {
 public:
 
-  JBIG2Stream(Stream *strA, Object *globalsStreamA);
-  virtual ~JBIG2Stream();
-  virtual StreamKind getKind() { return strJBIG2; }
-  virtual void reset();
-  virtual void close();
-  virtual Goffset getPos();
-  virtual int getChar();
-  virtual int lookChar();
-  virtual GooString *getPSFilter(int psLevel, const char *indent);
-  virtual GBool isBinary(GBool last = gTrue);
+  JBIG2Stream(Stream *strA, Object *globalsStreamA, Object *globalsStreamRefA);
+  ~JBIG2Stream();
+  StreamKind getKind() override { return strJBIG2; }
+  void reset() override;
+  void close() override;
+  Goffset getPos() override;
+  int getChar() override;
+  int lookChar() override;
+  GooString *getPSFilter(int psLevel, const char *indent) override;
+  bool isBinary(bool last = true) override;
+  virtual Object *getGlobalsStream() { return &globalsStream; }
+  virtual Ref getGlobalsStreamRef() { return globalsStreamRef; }
 
 private:
-  virtual GBool hasGetChars() { return true; }
-  virtual int getChars(int nChars, Guchar *buffer);
+  bool hasGetChars() override { return true; }
+  int getChars(int nChars, Guchar *buffer) override;
 
   void readSegments();
-  GBool readSymbolDictSeg(Guint segNum, Guint length,
+  bool readSymbolDictSeg(Guint segNum, Guint length,
 			  Guint *refSegs, Guint nRefSegs);
-  void readTextRegionSeg(Guint segNum, GBool imm,
-			 GBool lossless, Guint length,
+  void readTextRegionSeg(Guint segNum, bool imm,
+			 bool lossless, Guint length,
 			 Guint *refSegs, Guint nRefSegs);
-  JBIG2Bitmap *readTextRegion(GBool huff, GBool refine,
+  JBIG2Bitmap *readTextRegion(bool huff, bool refine,
 			      int w, int h,
 			      Guint numInstances,
 			      Guint logStrips,
@@ -89,26 +88,26 @@ private:
 			      Guint templ,
 			      int *atx, int *aty);
   void readPatternDictSeg(Guint segNum, Guint length);
-  void readHalftoneRegionSeg(Guint segNum, GBool imm,
-			     GBool lossless, Guint length,
+  void readHalftoneRegionSeg(Guint segNum, bool imm,
+			     bool lossless, Guint length,
 			     Guint *refSegs, Guint nRefSegs);
-  void readGenericRegionSeg(Guint segNum, GBool imm,
-			    GBool lossless, Guint length);
+  void readGenericRegionSeg(Guint segNum, bool imm,
+			    bool lossless, Guint length);
   void mmrAddPixels(int a1, int blackPixels,
 		    int *codingLine, int *a0i, int w);
   void mmrAddPixelsNeg(int a1, int blackPixels,
 		       int *codingLine, int *a0i, int w);
-  JBIG2Bitmap *readGenericBitmap(GBool mmr, int w, int h,
-				 int templ, GBool tpgdOn,
-				 GBool useSkip, JBIG2Bitmap *skip,
+  JBIG2Bitmap *readGenericBitmap(bool mmr, int w, int h,
+				 int templ, bool tpgdOn,
+				 bool useSkip, JBIG2Bitmap *skip,
 				 int *atx, int *aty,
 				 int mmrDataLength);
-  void readGenericRefinementRegionSeg(Guint segNum, GBool imm,
-				      GBool lossless, Guint length,
+  void readGenericRefinementRegionSeg(Guint segNum, bool imm,
+				      bool lossless, Guint length,
 				      Guint *refSegs,
 				      Guint nRefSegs);
   JBIG2Bitmap *readGenericRefinementRegion(int w, int h,
-					   int templ, GBool tpgrOn,
+					   int templ, bool tpgrOn,
 					   JBIG2Bitmap *refBitmap,
 					   int refDX, int refDY,
 					   int *atx, int *aty);
@@ -124,13 +123,14 @@ private:
   void resetRefinementStats(Guint templ,
 			    JArithmeticDecoderStats *prevStats);
   void resetIntStats(int symCodeLen);
-  GBool readUByte(Guint *x);
-  GBool readByte(int *x);
-  GBool readUWord(Guint *x);
-  GBool readULong(Guint *x);
-  GBool readLong(int *x);
+  bool readUByte(Guint *x);
+  bool readByte(int *x);
+  bool readUWord(Guint *x);
+  bool readULong(Guint *x);
+  bool readLong(int *x);
 
   Object globalsStream;
+  Ref globalsStreamRef;
   Guint pageW, pageH, curPageH;
   Guint pageDefPixel;
   JBIG2Bitmap *pageBitmap;
