@@ -4,7 +4,7 @@
 //
 // A JPX stream decoder using OpenJPEG
 //
-// Copyright 2008-2010, 2012, 2017 Albert Astals Cid <aacid@kde.org>
+// Copyright 2008-2010, 2012, 2017, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright 2011 Daniel Glöckner <daniel-gl@gmx.net>
 // Copyright 2014, 2016 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright 2013, 2014 Adrian Johnson <ajohnson@redneon.com>
@@ -39,13 +39,12 @@ struct JPXStreamPrivate {
   int ccounter;
   int npixels;
   int ncomps;
-  GBool indexed;
-  GBool inited;
+  bool inited;
   int smaskInData;
-  void init2(OPJ_CODEC_FORMAT format, unsigned char *data, int length, GBool indexed);
+  void init2(OPJ_CODEC_FORMAT format, unsigned char *data, int length, bool indexed);
 };
 
-static inline Guchar adjustComp(int r, int adjust, int depth, int sgndcorr, GBool indexed) {
+static inline Guchar adjustComp(int r, int adjust, int depth, int sgndcorr, bool indexed) {
   if (!indexed) {
     r += sgndcorr;
     if (adjust) {
@@ -77,11 +76,10 @@ static inline int doGetChar(JPXStreamPrivate* priv) {
 
 JPXStream::JPXStream(Stream *strA) : FilterStream(strA) {
   priv = new JPXStreamPrivate;
-  priv->inited = gFalse;
-  priv->image = NULL;
+  priv->inited = false;
+  priv->image = nullptr;
   priv->npixels = 0;
   priv->ncomps = 0;
-  priv->indexed = gFalse;
 }
 
 JPXStream::~JPXStream() {
@@ -96,9 +94,9 @@ void JPXStream::reset() {
 }
 
 void JPXStream::close() {
-  if (priv->image != NULL) {
+  if (priv->image != nullptr) {
     opj_image_destroy(priv->image);
-    priv->image = NULL;
+    priv->image = nullptr;
     priv->npixels = 0;
   }
 }
@@ -108,7 +106,7 @@ Goffset JPXStream::getPos() {
 }
 
 int JPXStream::getChars(int nChars, Guchar *buffer) {
-  if (unlikely(priv->inited == gFalse)) { init(); }
+  if (unlikely(priv->inited == false)) { init(); }
 
   for (int i = 0; i < nChars; ++i) {
     const int c = doGetChar(priv);
@@ -119,27 +117,27 @@ int JPXStream::getChars(int nChars, Guchar *buffer) {
 }
 
 int JPXStream::getChar() {
-  if (unlikely(priv->inited == gFalse)) { init(); }
+  if (unlikely(priv->inited == false)) { init(); }
 
   return doGetChar(priv);
 }
 
 int JPXStream::lookChar() {
-  if (unlikely(priv->inited == gFalse)) { init(); }
+  if (unlikely(priv->inited == false)) { init(); }
 
   return doLookChar(priv);
 }
 
 GooString *JPXStream::getPSFilter(int psLevel, const char *indent) {
-  return NULL;
+  return nullptr;
 }
 
-GBool JPXStream::isBinary(GBool last) {
-  return str->isBinary(gTrue);
+bool JPXStream::isBinary(bool last) {
+  return str->isBinary(true);
 }
 
 void JPXStream::getImageParams(int *bitsPerComponent, StreamColorSpaceMode *csMode) {
-  if (unlikely(priv->inited == gFalse)) { init(); }
+  if (unlikely(priv->inited == false)) { init(); }
 
   *bitsPerComponent = 8;
   int numComps = (priv->image) ? priv->image->numcomps : 1;
@@ -223,9 +221,10 @@ void JPXStream::init()
   int bufSize = BUFFER_INITIAL_SIZE;
   if (oLen.isInt()) bufSize = oLen.getInt();
 
+  bool indexed = false;
   if (cspace.isArray() && cspace.arrayGetLength() > 0) {
-    Object cstype = cspace.arrayGet(0);
-    if (cstype.isName("Indexed")) priv->indexed = gTrue;
+    const Object cstype = cspace.arrayGet(0);
+    if (cstype.isName("Indexed")) indexed = true;
   }
 
   priv->smaskInData = 0;
@@ -233,7 +232,7 @@ void JPXStream::init()
 
   int length = 0;
   unsigned char *buf = str->toUnsignedChars(&length, bufSize);
-  priv->init2(OPJ_CODEC_JP2, buf, length, priv->indexed);
+  priv->init2(OPJ_CODEC_JP2, buf, length, indexed);
   gfree(buf);
 
   if (priv->image) {
@@ -250,7 +249,7 @@ void JPXStream::init()
     priv->ncomps = priv->image->numcomps;
     if (alpha == 1 && priv->smaskInData == 0) priv->ncomps--;
     for (int component = 0; component < priv->ncomps; component++) {
-      if (priv->image->comps[component].data == NULL) {
+      if (priv->image->comps[component].data == nullptr) {
         close();
         break;
       }
@@ -264,7 +263,7 @@ void JPXStream::init()
 	sgndcorr = 1 << (priv->image->comps[0].prec - 1);
       for (int i = 0; i < priv->npixels; i++) {
 	int r = priv->image->comps[component].data[i];
-	*(cdata++) = adjustComp(r, adjust, depth, sgndcorr, priv->indexed);
+	*(cdata++) = adjustComp(r, adjust, depth, sgndcorr, indexed);
       }
     }
   } else {
@@ -273,10 +272,10 @@ void JPXStream::init()
 
   priv->counter = 0;
   priv->ccounter = 0;
-  priv->inited = gTrue;
+  priv->inited = true;
 }
 
-void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int length, GBool indexed)
+void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int length, bool indexed)
 {
   JPXData jpxData;
 
@@ -289,7 +288,7 @@ void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int le
   stream = opj_stream_default_create(OPJ_TRUE);
 
 #if OPENJPEG_VERSION >= OPENJPEG_VERSION_ENCODE(2, 1, 0)
-  opj_stream_set_user_data (stream, &jpxData, NULL);
+  opj_stream_set_user_data (stream, &jpxData, nullptr);
 #else
   opj_stream_set_user_data (stream, &jpxData);
 #endif
@@ -310,14 +309,14 @@ void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int le
 
   /* Get the decoder handle of the format */
   decoder = opj_create_decompress(format);
-  if (decoder == NULL) {
+  if (decoder == nullptr) {
     error(errSyntaxWarning, -1, "Unable to create decoder");
     goto error;
   }
 
   /* Catch events using our callbacks */
-  opj_set_warning_handler(decoder, libopenjpeg_warning_callback, NULL);
-  opj_set_error_handler(decoder, libopenjpeg_error_callback, NULL);
+  opj_set_warning_handler(decoder, libopenjpeg_warning_callback, nullptr);
+  opj_set_error_handler(decoder, libopenjpeg_error_callback, nullptr);
 
   /* Setup the decoder decoding parameters */
   if (!opj_setup_decoder(decoder, &parameters)) {
@@ -326,7 +325,7 @@ void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int le
   }
 
   /* Decode the stream and fill the image structure */
-  image = NULL;
+  image = nullptr;
   if (!opj_read_header(stream, decoder, &image)) {
     error(errSyntaxWarning, -1, "Unable to read header");
     goto error;
@@ -348,7 +347,7 @@ void JPXStreamPrivate::init2(OPJ_CODEC_FORMAT format, unsigned char *buf, int le
   opj_destroy_codec(decoder);
   opj_stream_destroy(stream);
 
-  if (image != NULL)
+  if (image != nullptr)
     return;
 
 error:
