@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2005 Jeff Muizelaar <jeff@infidigm.net>
-// Copyright (C) 2005-2013, 2016, 2017 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005-2013, 2016-2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2006-2008 Pino Toscano <pino@kde.org>
 // Copyright (C) 2006 Nickolay V. Shmyrev <nshmyrev@yandex.ru>
 // Copyright (C) 2006 Scott Turner <scotty1024@mac.com>
@@ -29,6 +29,7 @@
 // Copyright (C) 2013 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2015 Philipp Reinkemeier <philipp.reinkemeier@offis.de>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -37,10 +38,6 @@
 
 #include <config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <stddef.h>
 #include <limits.h>
 #include "GlobalParams.h"
@@ -61,11 +58,6 @@
 #include "Catalog.h"
 #include "Form.h"
 
-#ifdef MULTITHREADED
-#  define pageLocker()   MutexLocker locker(&mutex)
-#else
-#  define pageLocker()
-#endif
 //------------------------------------------------------------------------
 // PDFRectangle
 //------------------------------------------------------------------------
@@ -100,7 +92,7 @@ void PDFRectangle::clipTo(PDFRectangle *rect) {
 PageAttrs::PageAttrs(PageAttrs *attrs, Dict *dict) {
   Object obj1;
   PDFRectangle mBox;
-  const GBool isPage = dict->is("Page");
+  const bool isPage = dict->is("Page");
 
   // get old/default values
   if (attrs) {
@@ -117,7 +109,7 @@ PageAttrs::PageAttrs(PageAttrs *attrs, Dict *dict) {
     mediaBox.x2 = 612;
     mediaBox.y2 = 792;
     cropBox.x1 = cropBox.y1 = cropBox.x2 = cropBox.y2 = 0;
-    haveCropBox = gFalse;
+    haveCropBox = false;
     rotate = 0;
     resources.setToNull();
   }
@@ -129,7 +121,7 @@ PageAttrs::PageAttrs(PageAttrs *attrs, Dict *dict) {
 
   // crop box
   if (readBox(dict, "CropBox", &cropBox)) {
-    haveCropBox = gTrue;
+    haveCropBox = true;
   }
   if (!haveCropBox) {
     cropBox = mediaBox;
@@ -194,41 +186,41 @@ void PageAttrs::clipBoxes() {
   artBox.clipTo(&mediaBox);
 }
 
-GBool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box) {
+bool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box) {
   PDFRectangle tmp;
   double t;
   Object obj1, obj2;
-  GBool ok;
+  bool ok;
 
   obj1 = dict->lookup(key);
   if (obj1.isArray() && obj1.arrayGetLength() == 4) {
-    ok = gTrue;
+    ok = true;
     obj2 = obj1.arrayGet(0);
     if (obj2.isNum()) {
       tmp.x1 = obj2.getNum();
     } else {
-      ok = gFalse;
+      ok = false;
     }
     obj2 = obj1.arrayGet(1);
     if (obj2.isNum()) {
       tmp.y1 = obj2.getNum();
     } else {
-      ok = gFalse;
+      ok = false;
     }
     obj2 = obj1.arrayGet(2);
     if (obj2.isNum()) {
       tmp.x2 = obj2.getNum();
     } else {
-      ok = gFalse;
+      ok = false;
     }
     obj2 = obj1.arrayGet(3);
     if (obj2.isNum()) {
       tmp.y2 = obj2.getNum();
     } else {
-      ok = gFalse;
+      ok = false;
     }
     if (tmp.x1 == 0 && tmp.x2 == 0 && tmp.y1 == 0 && tmp.y2 == 0)
-      ok = gFalse;
+      ok = false;
     if (ok) {
       if (tmp.x1 > tmp.x2) {
 	t = tmp.x1; tmp.x1 = tmp.x2; tmp.x2 = t;
@@ -239,7 +231,7 @@ GBool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box) {
       *box = tmp;
     }
   } else {
-    ok = gFalse;
+    ok = false;
   }
   return ok;
 }
@@ -248,16 +240,15 @@ GBool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box) {
 // Page
 //------------------------------------------------------------------------
 
+#define pageLocker()   std::unique_lock<std::recursive_mutex> locker(mutex)
+
 Page::Page(PDFDoc *docA, int numA, Object *pageDict, Ref pageRefA, PageAttrs *attrsA, Form *form) {
-#ifdef MULTITHREADED
-  gInitMutex(&mutex);
-#endif
-  ok = gTrue;
+  ok = true;
   doc = docA;
   xref = doc->getXRef();
   num = numA;
   duration = -1;
-  annots = NULL;
+  annots = nullptr;
 
   pageObj = pageDict->copy();
   pageRef = pageRefA;
@@ -322,15 +313,12 @@ Page::Page(PDFDoc *docA, int numA, Object *pageDict, Ref pageRefA, PageAttrs *at
   annotsObj.setToNull();
  err1:
   contents.setToNull();
-  ok = gFalse;
+  ok = false;
 }
 
 Page::~Page() {
   delete attrs;
   delete annots;
-#ifdef MULTITHREADED
-  gDestroyMutex(&mutex);
-#endif
 }
 
 Dict *Page::getResourceDict() { 
@@ -345,7 +333,7 @@ Object *Page::getResourceDictObject()
 Dict *Page::getResourceDictCopy(XRef *xrefA) { 
   pageLocker();
   Dict *dict = attrs->getResourceDict();
-  return dict ? dict->copy(xrefA) : NULL;
+  return dict ? dict->copy(xrefA) : nullptr;
 }
 
 void Page::replaceXRef(XRef *xrefA) {
@@ -416,7 +404,7 @@ void Page::addAnnot(Annot *annot) {
       static_cast<AnnotPopup*>(annot)->getParentNF()->isNull()) {
     annots->appendAnnot(annot);
   }
-  annot->setPage(num, gTrue);
+  annot->setPage(num, true);
 
   AnnotMarkup *annotMarkup = dynamic_cast<AnnotMarkup*>(annot);
   if (annotMarkup) {
@@ -459,7 +447,7 @@ void Page::removeAnnot(Annot *annot) {
     }
   }
   annot->removeReferencedObjects(); // Note: Might recurse in removeAnnot again
-  annot->setPage(0, gFalse);
+  annot->setPage(0, false);
 }
 
 Links *Page::getLinks() {
@@ -471,25 +459,25 @@ FormPageWidgets *Page::getFormWidgets() {
 }
 
 void Page::display(OutputDev *out, double hDPI, double vDPI,
-		   int rotate, GBool useMediaBox, GBool crop,
-		   GBool printing,
-		   GBool (*abortCheckCbk)(void *data),
+		   int rotate, bool useMediaBox, bool crop,
+		   bool printing,
+		   bool (*abortCheckCbk)(void *data),
 		   void *abortCheckCbkData,
-                   GBool (*annotDisplayDecideCbk)(Annot *annot, void *user_data),
+                   bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data),
                    void *annotDisplayDecideCbkData,
-                   GBool copyXRef) {
+                   bool copyXRef) {
   displaySlice(out, hDPI, vDPI, rotate, useMediaBox, crop, -1, -1, -1, -1, printing,
 	       abortCheckCbk, abortCheckCbkData,
                annotDisplayDecideCbk, annotDisplayDecideCbkData, copyXRef);
 }
 
 Gfx *Page::createGfx(OutputDev *out, double hDPI, double vDPI,
-		     int rotate, GBool useMediaBox, GBool crop,
+		     int rotate, bool useMediaBox, bool crop,
 		     int sliceX, int sliceY, int sliceW, int sliceH,
-		     GBool printing,
-		     GBool (*abortCheckCbk)(void *data),
+		     bool printing,
+		     bool (*abortCheckCbk)(void *data),
 		     void *abortCheckCbkData, XRef *xrefA) {
-  PDFRectangle *mediaBox, *cropBox;
+  const PDFRectangle *mediaBox, *cropBox;
   PDFRectangle box;
   Gfx *gfx;
 
@@ -517,21 +505,21 @@ Gfx *Page::createGfx(OutputDev *out, double hDPI, double vDPI,
     crop = (box == *cropBox) && out->needClipToCropBox();
   }
   gfx = new Gfx(doc, out, num, attrs->getResourceDict(),
-		hDPI, vDPI, &box, crop ? cropBox : (PDFRectangle *)NULL,
+		hDPI, vDPI, &box, crop ? cropBox : nullptr,
 		rotate, abortCheckCbk, abortCheckCbkData, xrefA);
 
   return gfx;
 }
 
 void Page::displaySlice(OutputDev *out, double hDPI, double vDPI,
-			int rotate, GBool useMediaBox, GBool crop,
+			int rotate, bool useMediaBox, bool crop,
 			int sliceX, int sliceY, int sliceW, int sliceH,
-			GBool printing,
-			GBool (*abortCheckCbk)(void *data),
+			bool printing,
+			bool (*abortCheckCbk)(void *data),
 			void *abortCheckCbkData,
-                        GBool (*annotDisplayDecideCbk)(Annot *annot, void *user_data),
+                        bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data),
                         void *annotDisplayDecideCbkData,
-                        GBool copyXRef) {
+                        bool copyXRef) {
   Gfx *gfx;
   Annots *annotList;
   int i;
@@ -599,7 +587,7 @@ void Page::display(Gfx *gfx) {
   }
 }
 
-GBool Page::loadThumb(unsigned char **data_out,
+bool Page::loadThumb(unsigned char **data_out,
 		      int *width_out, int *height_out,
 		      int *rowstride_out)
 {
@@ -608,7 +596,7 @@ GBool Page::loadThumb(unsigned char **data_out,
   Object obj1;
   Dict *dict;
   GfxColorSpace *colorSpace;
-  GBool success = gFalse;
+  bool success = false;
   Stream *str;
   GfxImageColorMap *colorMap;
 
@@ -616,7 +604,7 @@ GBool Page::loadThumb(unsigned char **data_out,
   pageLocker();
   Object fetched_thumb = thumb.fetch(xref);
   if (!fetched_thumb.isStream()) {
-    return gFalse;
+    return false;
   }
 
   dict = fetched_thumb.streamGetDict();
@@ -641,7 +629,7 @@ GBool Page::loadThumb(unsigned char **data_out,
   if (obj1.isNull ()) {
     obj1 = dict->lookup ("CS");
   }
-  colorSpace = GfxColorSpace::parse(NULL, &obj1, NULL, NULL);
+  colorSpace = GfxColorSpace::parse(nullptr, &obj1, nullptr, nullptr);
   if (!colorSpace) {
     fprintf (stderr, "Error: Cannot parse color space\n");
     goto fail1;
@@ -683,7 +671,7 @@ GBool Page::loadThumb(unsigned char **data_out,
     delete imgstr;
   }
 
-  success = gTrue;
+  success = true;
 
   if (width_out)
     *width_out = width;
@@ -698,10 +686,10 @@ GBool Page::loadThumb(unsigned char **data_out,
 }
 
 void Page::makeBox(double hDPI, double vDPI, int rotate,
-		   GBool useMediaBox, GBool upsideDown,
+		   bool useMediaBox, bool upsideDown,
 		   double sliceX, double sliceY, double sliceW, double sliceH,
-		   PDFRectangle *box, GBool *crop) {
-  PDFRectangle *mediaBox, *cropBox, *baseBox;
+		   PDFRectangle *box, bool *crop) {
+  const PDFRectangle *mediaBox, *cropBox, *baseBox;
   double kx, ky;
 
   mediaBox = getMediaBox();
@@ -755,7 +743,7 @@ void Page::makeBox(double hDPI, double vDPI, int rotate,
     *box = *mediaBox;
   } else {
     *box = *cropBox;
-    *crop = gFalse;
+    *crop = false;
   }
 }
 
@@ -771,7 +759,7 @@ void Page::processLinks(OutputDev *out) {
 }
 
 void Page::getDefaultCTM(double *ctm, double hDPI, double vDPI,
-			 int rotate, GBool useMediaBox, GBool upsideDown) {
+			 int rotate, bool useMediaBox, bool upsideDown) {
   GfxState *state;
   int i;
   rotate += getRotate();
@@ -794,7 +782,7 @@ LinkAction* Page::getAdditionalAction(PageAdditionalActionsType type) {
   Object additionalActionsObject = actions.fetch(doc->getXRef());
   if (additionalActionsObject.isDict()) {
     const char *key = (type == actionOpenPage ?  "O" :
-                       type == actionClosePage ? "C" : NULL);
+                       type == actionClosePage ? "C" : nullptr);
 
     Object actionObject = additionalActionsObject.dictLookup(key);
     if (actionObject.isDict())
