@@ -23,6 +23,7 @@
 // Copyright (C) 2012, 2013 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -32,22 +33,16 @@
 #ifndef XREF_H
 #define XREF_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include "poppler-config.h"
 #include "goo/gtypes.h"
-#include "goo/GooMutex.h"
 #include "Object.h"
 #include "Stream.h"
-
-#include <vector>
+#include "PopplerCache.h"
 
 class Dict;
 class Stream;
 class Parser;
-class PopplerCache;
+class ObjectStream;
 
 //------------------------------------------------------------------------
 // XRef
@@ -76,12 +71,12 @@ struct XRefEntry {
     DontRewrite  // Entry must not be written back in case of full rewrite
   };
 
-  inline GBool getFlag(Flag flag) {
+  inline bool getFlag(Flag flag) const {
     const int mask = (1 << (int)flag);
     return (flags & mask) != 0;
   }
 
-  inline void setFlag(Flag flag, GBool value) {
+  inline void setFlag(Flag flag, bool value) {
     const int mask = (1 << (int)flag);
     if (value) {
       flags |= mask;
@@ -97,9 +92,9 @@ public:
   // Constructor, create an empty XRef, used for PDF writing
   XRef();
   // Constructor, create an empty XRef but with info dict, used for PDF writing
-  XRef(Object *trailerDictA);
+  XRef(const Object *trailerDictA);
   // Constructor.  Read xref table from stream.
-  XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA = 0, GBool *wasReconstructed = NULL, GBool reconstruct = false);
+  XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA = 0, bool *wasReconstructed = nullptr, bool reconstruct = false);
 
   // Destructor.
   ~XRef();
@@ -108,20 +103,20 @@ public:
   XRef& operator=(const XRef &) = delete;
 
   // Copy xref but with new base stream!
-  XRef *copy();
+  XRef *copy() const;
 
   // Is xref table valid?
-  GBool isOk() { return ok; }
+  bool isOk() const { return ok; }
 
   // Is the last XRef section a stream or a table?
-  GBool isXRefStream() { return xRefStream; }
+  bool isXRefStream() const { return xRefStream; }
 
   // Get the error code (if isOk() returns false).
-  int getErrorCode() { return errCode; }
+  int getErrorCode() const { return errCode; }
 
   // Set the encryption parameters.
-  void setEncryption(int permFlagsA, GBool ownerPasswordOkA,
-		     Guchar *fileKeyA, int keyLengthA,
+  void setEncryption(int permFlagsA, bool ownerPasswordOkA,
+		     const Guchar *fileKeyA, int keyLengthA,
 		     int encVersionA, int encRevisionA,
 		     CryptAlgorithm encAlgorithmA);
   // Mark Encrypt entry as Unencrypted
@@ -130,18 +125,18 @@ public:
   void getEncryptionParameters(Guchar **fileKeyA, CryptAlgorithm *encAlgorithmA, int *keyLengthA);
 
   // Is the file encrypted?
-  GBool isEncrypted() { return encrypted; }
+  bool isEncrypted() const { return encrypted; }
 
   // Check various permissions.
-  GBool okToPrint(GBool ignoreOwnerPW = gFalse);
-  GBool okToPrintHighRes(GBool ignoreOwnerPW = gFalse);
-  GBool okToChange(GBool ignoreOwnerPW = gFalse);
-  GBool okToCopy(GBool ignoreOwnerPW = gFalse);
-  GBool okToAddNotes(GBool ignoreOwnerPW = gFalse);
-  GBool okToFillForm(GBool ignoreOwnerPW = gFalse);
-  GBool okToAccessibility(GBool ignoreOwnerPW = gFalse);
-  GBool okToAssemble(GBool ignoreOwnerPW = gFalse);
-  int getPermFlags() { return permFlags; }
+  bool okToPrint(bool ignoreOwnerPW = false) const;
+  bool okToPrintHighRes(bool ignoreOwnerPW = false) const;
+  bool okToChange(bool ignoreOwnerPW = false) const;
+  bool okToCopy(bool ignoreOwnerPW = false) const;
+  bool okToAddNotes(bool ignoreOwnerPW = false) const;
+  bool okToFillForm(bool ignoreOwnerPW = false) const;
+  bool okToAccessibility(bool ignoreOwnerPW = false) const;
+  bool okToAssemble(bool ignoreOwnerPW = false) const;
+  int getPermFlags() const { return permFlags; }
 
   // Get catalog object.
   Object getCatalog();
@@ -161,15 +156,15 @@ public:
   void removeDocInfo();
 
   // Return the number of objects in the xref table.
-  int getNumObjects() { return size; }
+  int getNumObjects() const { return size; }
 
   // Return the catalog object reference.
-  int getRootNum() { return rootNum; }
-  int getRootGen() { return rootGen; }
+  int getRootNum() const { return rootNum; }
+  int getRootGen() const { return rootGen; }
 
   // Get end position for a stream in a damaged file.
   // Returns false if unknown or file is not damaged.
-  GBool getStreamEnd(Goffset streamStart, Goffset *streamEnd);
+  bool getStreamEnd(Goffset streamStart, Goffset *streamEnd);
 
   // Retuns the entry that belongs to the offset
   int getNumEntry(Goffset offset);
@@ -183,22 +178,22 @@ public:
   void scanSpecialFlags();
 
   // Direct access.
-  XRefEntry *getEntry(int i, GBool complainIfMissing = gTrue);
+  XRefEntry *getEntry(int i, bool complainIfMissing = true);
   Object *getTrailerDict() { return &trailerDict; }
 
   // Was the XRef modified?
-  GBool isModified() { return modified; }
+  bool isModified() const { return modified; }
   // Set the modification flag for XRef to true.
-  void setModified() { modified = gTrue; }
+  void setModified() { modified = true; }
 
   // Write access
-  void setModifiedObject(Object* o, Ref r);
-  Ref addIndirectObject (Object* o);
+  void setModifiedObject(const Object* o, Ref r);
+  Ref addIndirectObject (const Object* o);
   void removeIndirectObject(Ref r);
-  void add(int num, int gen,  Goffset offs, GBool used);
+  void add(int num, int gen,  Goffset offs, bool used);
 
   // Output XRef table to stream
-  void writeTableToFile(OutStream* outStr, GBool writeAllEntries);
+  void writeTableToFile(OutStream* outStr, bool writeAllEntries);
   // Output XRef stream contents to GooString and fill trailerDict fields accordingly
   void writeStreamToBuffer(GooString *stmBuf, Dict *xrefDict, XRef *xref);
 
@@ -215,43 +210,40 @@ private:
   int capacity;			// size of <entries> array
   int size;			// number of entries
   int rootNum, rootGen;		// catalog dict
-  GBool ok;			// true if xref table is valid
+  bool ok;			// true if xref table is valid
   int errCode;			// error code (if <ok> is false)
-  GBool xrefReconstructed;	// marker, true if xref was already reconstructed
+  bool xrefReconstructed;	// marker, true if xref was already reconstructed
   Object trailerDict;		// trailer dictionary
-  GBool modified;
+  bool modified;
   Goffset *streamEnds;		// 'endstream' positions - only used in
 				//   damaged files
   int streamEndsLen;		// number of valid entries in streamEnds
-  PopplerCache *objStrs;	// cached object streams
-  GBool encrypted;		// true if file is encrypted
+  PopplerCache<Goffset, ObjectStream> objStrs;	// cached object streams
+  bool encrypted;		// true if file is encrypted
   int encRevision;		
   int encVersion;		// encryption algorithm
   CryptAlgorithm encAlgorithm;	// encryption algorithm
   int keyLength;		// length of key, in bytes
   int permFlags;		// permission bits
   Guchar fileKey[32];		// file decryption key
-  GBool ownerPasswordOk;	// true if owner password is correct
+  bool ownerPasswordOk;	// true if owner password is correct
   Goffset prevXRefOffset;		// position of prev XRef section (= next to read)
   Goffset mainXRefEntriesOffset; // offset of entries in main XRef table
-  GBool xRefStream;		// true if last XRef section is a stream
+  bool xRefStream;		// true if last XRef section is a stream
   Goffset mainXRefOffset;	// position of the main XRef table/stream
-  GBool scannedSpecialFlags;	// true if scanSpecialFlags has been called
-  GBool strOwner;     // true if str is owned by the instance
-#ifdef MULTITHREADED
-  GooMutex mutex;
-#endif
+  bool scannedSpecialFlags;	// true if scanSpecialFlags has been called
+  bool strOwner;     // true if str is owned by the instance
+  mutable std::recursive_mutex mutex;
 
-  void init();
   int reserve(int newSize);
   int resize(int newSize);
-  GBool readXRef(Goffset *pos, std::vector<Goffset> *followedXRefStm, std::vector<int> *xrefStreamObjsNum);
-  GBool readXRefTable(Parser *parser, Goffset *pos, std::vector<Goffset> *followedXRefStm, std::vector<int> *xrefStreamObjsNum);
-  GBool readXRefStreamSection(Stream *xrefStr, int *w, int first, int n);
-  GBool readXRefStream(Stream *xrefStr, Goffset *pos);
-  GBool constructXRef(GBool *wasReconstructed, GBool needCatalogDict = gFalse);
-  GBool parseEntry(Goffset offset, XRefEntry *entry);
-  void readXRefUntil(int untilEntryNum, std::vector<int> *xrefStreamObjsNum = NULL);
+  bool readXRef(Goffset *pos, std::vector<Goffset> *followedXRefStm, std::vector<int> *xrefStreamObjsNum);
+  bool readXRefTable(Parser *parser, Goffset *pos, std::vector<Goffset> *followedXRefStm, std::vector<int> *xrefStreamObjsNum);
+  bool readXRefStreamSection(Stream *xrefStr, int *w, int first, int n);
+  bool readXRefStream(Stream *xrefStr, Goffset *pos);
+  bool constructXRef(bool *wasReconstructed, bool needCatalogDict = false);
+  bool parseEntry(Goffset offset, XRefEntry *entry);
+  void readXRefUntil(int untilEntryNum, std::vector<int> *xrefStreamObjsNum = nullptr);
   void markUnencrypted(Object *obj);
 
   class XRefWriter {
@@ -294,10 +286,10 @@ private:
     void startSection(int first, int count) override;
     void writeEntry(Goffset offset, int gen, XRefEntryType type) override;
 
-    GBool hasOffsetsBeyond4GB;
+    bool hasOffsetsBeyond4GB;
   };
 
-  void writeXRef(XRefWriter *writer, GBool writeAllEntries);
+  void writeXRef(XRefWriter *writer, bool writeAllEntries);
 };
 
 #endif
