@@ -14,7 +14,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2005 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2010 Pino Toscano <pino@kde.org>
 // Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
@@ -30,10 +30,6 @@
 #ifndef ARTHUROUTPUTDEV_H
 #define ARTHUROUTPUTDEV_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include <memory>
 #include <map>
 #include <stack>
@@ -81,25 +77,25 @@ public:
 
   // Does this device use upside-down coordinates?
   // (Upside-down means (0,0) is the top left corner of the page.)
-  GBool upsideDown() override { return gTrue; }
+  bool upsideDown() override { return true; }
 
   // Does this device use drawChar() or drawString()?
-  GBool useDrawChar() override { return gTrue; }
+  bool useDrawChar() override { return true; }
 
   // Does this device implement shaded fills (aka gradients) natively?
   // If this returns false, these shaded fills
   // will be reduced to a series of other drawing operations.
   // type==2 is 'axial shading'
-  GBool useShadedFills(int type) override { return type == 2; }
+  bool useShadedFills(int type) override { return type == 2; }
 
   // Does this device use beginType3Char/endType3Char?  Otherwise,
   // text in Type 3 fonts will be drawn with drawChar/drawString.
-  GBool interpretType3Chars() override { return gFalse; }
+  bool interpretType3Chars() override { return false; }
 
   //----- initialization and control
 
   // Set Current Transformation Matrix to a fixed matrix given in ctm[0],...,ctm[5]
-  void setDefaultCTM(double *ctm) override;
+  void setDefaultCTM(const double *ctm) override;
 
   // Start a page.
   void startPage(int pageNum, GfxState *state, XRef *xref) override;
@@ -134,7 +130,7 @@ public:
   void stroke(GfxState *state) override;
   void fill(GfxState *state) override;
   void eoFill(GfxState *state) override;
-  GBool axialShadedFill(GfxState * state, GfxAxialShading *shading, double tMin, double tMax) override;
+  bool axialShadedFill(GfxState * state, GfxAxialShading *shading, double tMin, double tMax) override;
 
   //----- path clipping
   void clip(GfxState *state) override;
@@ -150,20 +146,20 @@ public:
 
   //----- image drawing
   void drawImageMask(GfxState *state, Object *ref, Stream *str,
-		     int width, int height, GBool invert,
-		     GBool interpolate, GBool inlineImg) override;
+		     int width, int height, bool invert,
+		     bool interpolate, bool inlineImg) override;
   void drawImage(GfxState *state, Object *ref, Stream *str,
 		 int width, int height, GfxImageColorMap *colorMap,
-		 GBool interpolate, int *maskColors, GBool inlineImg) override;
+		 bool interpolate, int *maskColors, bool inlineImg) override;
 
   void drawSoftMaskedImage(GfxState *state, Object *ref, Stream *str,
                            int width, int height,
                            GfxImageColorMap *colorMap,
-                           GBool interpolate,
+                           bool interpolate,
                            Stream *maskStr,
                            int maskWidth, int maskHeight,
                            GfxImageColorMap *maskColorMap,
-                           GBool maskInterpolate) override;
+                           bool maskInterpolate) override;
 
   //----- Type 3 font operators
   void type3D0(GfxState *state, double wx, double wy) override;
@@ -171,19 +167,19 @@ public:
 	       double llx, double lly, double urx, double ury) override;
 
   //----- transparency groups and soft masks
-  virtual void beginTransparencyGroup(GfxState *state, double *bbox,
+  virtual void beginTransparencyGroup(GfxState *state, const double *bbox,
                                       GfxColorSpace *blendingColorSpace,
-                                      GBool isolated, GBool knockout,
-                                      GBool forSoftMask) override;
+                                      bool isolated, bool knockout,
+                                      bool forSoftMask) override;
   virtual void endTransparencyGroup(GfxState *state) override;
-  virtual void paintTransparencyGroup(GfxState *state, double *bbox) override;
+  virtual void paintTransparencyGroup(GfxState *state, const double *bbox) override;
 
   //----- special access
 
   // Called to indicate that a new PDF document has been loaded.
   void startDoc(PDFDoc* doc);
 
-  GBool isReverseVideo() { return gFalse; }
+  bool isReverseVideo() { return false; }
   
 private:
 
@@ -208,7 +204,7 @@ private:
   QBrush m_currentBrush;
   std::stack<QBrush> m_currentBrushStack;
 
-  GBool m_needFontUpdate;		// set when the font needs to be updated
+  bool m_needFontUpdate;		// set when the font needs to be updated
   SplashFontEngine *m_fontEngine;
   PDFDoc* m_doc;
   XRef *xref;			// xref table for current document
