@@ -76,8 +76,8 @@ FormField::FormField(FormFieldData &dd)
   double left, top, right, bottom;
   m_formData->fm->getRect(&left, &bottom, &right, &top);
   // build a normalized transform matrix for this page at 100% scale
-  GfxState gfxState( 72.0, 72.0, m_formData->page->getCropBox(), rotation, gTrue );
-  double * gfxCTM = gfxState.getCTM();
+  GfxState gfxState( 72.0, 72.0, m_formData->page->getCropBox(), rotation, true );
+  const double * gfxCTM = gfxState.getCTM();
   double MTX[6];
   double pageWidth = m_formData->page->getCropWidth();
   double pageHeight = m_formData->page->getCropHeight();
@@ -291,7 +291,7 @@ bool FormFieldButton::state() const
 void FormFieldButton::setState( bool state )
 {
   FormWidgetButton* fwb = static_cast<FormWidgetButton*>(m_formData->fm);
-  fwb->setState((GBool)state);
+  fwb->setState((bool)state);
 }
 
 QList<int> FormFieldButton::siblings() const
@@ -496,7 +496,8 @@ bool FormFieldChoice::canBeSpellChecked() const
 }
 
 
-struct SignatureValidationInfoPrivate {
+class SignatureValidationInfoPrivate {
+public:
 	SignatureValidationInfo::SignatureStatus signature_status;
 	SignatureValidationInfo::CertificateStatus certificate_status;
 
