@@ -17,9 +17,11 @@
  * Copyright (C) 2015 William Bader <williambader@hotmail.com>
  * Copyright (C) 2016 Arseniy Lartsev <arseniy@alumni.chalmers.se>
  * Copyright (C) 2016, Hanno Meyer-Thurow <h.mth@web.de>
- * Copyright (C) 2017, Oliver Sander <oliver.sander@tu-dresden.de>
+ * Copyright (C) 2017, 2018, Oliver Sander <oliver.sander@tu-dresden.de>
  * Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
  * Copyright (C) 2017, 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
+ * Copyright (C) 2018 Intevation GmbH <intevation@intevation.de>
+ * Copyright (C) 2018, Tobias Deiminger <haxtibal@posteo.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -104,9 +106,9 @@ class Qt5SplashOutputDev : public SplashOutputDev, public OutputDevCallbackHelpe
 {
 public:
   Qt5SplashOutputDev(SplashColorMode colorModeA, int bitmapRowPadA,
-                      GBool reverseVideoA, bool ignorePaperColorA, SplashColorPtr paperColorA,
-                      GBool bitmapTopDownA, SplashThinLineMode thinLineMode,
-                      GBool overprintPreviewA)
+                      bool reverseVideoA, bool ignorePaperColorA, SplashColorPtr paperColorA,
+                      bool bitmapTopDownA, SplashThinLineMode thinLineMode,
+                      bool overprintPreviewA)
     : SplashOutputDev(colorModeA, bitmapRowPadA, reverseVideoA, paperColorA, bitmapTopDownA, thinLineMode, overprintPreviewA)
     , ignorePaperColor(ignorePaperColorA)
   {
@@ -226,7 +228,7 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
     case actionLaunch:
     {
       LinkLaunch * e = (LinkLaunch *)a;
-      GooString * p = e->getParams();
+      const GooString * p = e->getParams();
       popplerLink = new LinkExecute( linkArea, e->getFileName()->getCString(), p ? p->getCString() : nullptr );
     }
     break;
@@ -342,11 +344,35 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
       LinkOCGStatePrivate *locgp = new LinkOCGStatePrivate( linkArea, plocg );
       popplerLink = new LinkOCGState( locgp );
     }
+    break;
+
+    case actionHide:
+    {
+      ::LinkHide *lh = (::LinkHide *)a;
+
+      LinkHidePrivate *lhp = new LinkHidePrivate( linkArea, lh->hasTargetName() ? UnicodeParsedString( lh->getTargetName() ) : QString(), lh->isShowAction() );
+      popplerLink = new LinkHide( lhp );
+    }
+    break;
 
     case actionUnknown:
     break;
   }
 
+  if ( popplerLink )
+  {
+    const GooList *nextActions = a->nextActions();
+    if ( nextActions )
+    {
+      QVector<Link *> links;
+      for ( int i = 0; i < nextActions->getLength(); ++i )
+      {
+        links << convertLinkActionToLink( static_cast< ::LinkAction * >( nextActions->get( i ) ), parentDoc, linkArea );
+      }
+      LinkPrivate::get(popplerLink)->nextLinks = links;
+    }
+  }
+
   return popplerLink;
 }
 
@@ -360,36 +386,36 @@ inline TextPage *PageData::prepareTextSearch(const QString &text, Page::Rotation
   const int rotation = (int)rotate * 90;
 
   // fetch ourselves a textpage
-  TextOutputDev td(nullptr, gTrue, 0, gFalse, gFalse);
+  TextOutputDev td(nullptr, true, 0, false, false);
   parentDoc->doc->displayPage( &td, index + 1, 72, 72, rotation, false, true, false,
-    nullptr, nullptr, nullptr, nullptr, gTrue);
+    nullptr, nullptr, nullptr, nullptr, true);
   TextPage *textPage=td.takeText();
 
   return textPage;
 }
 
-inline GBool PageData::performSingleTextSearch(TextPage* textPage, QVector<Unicode> &u, double &sLeft, double &sTop, double &sRight, double &sBottom, Page::SearchDirection direction, GBool sCase, GBool sWords)
+inline bool PageData::performSingleTextSearch(TextPage* textPage, QVector<Unicode> &u, double &sLeft, double &sTop, double &sRight, double &sBottom, Page::SearchDirection direction, bool sCase, bool sWords)
 {
   if (direction == Page::FromTop)
     return textPage->findText( u.data(), u.size(),
-           gTrue, gTrue, gFalse, gFalse, sCase, gFalse, sWords, &sLeft, &sTop, &sRight, &sBottom );
+           true, true, false, false, sCase, false, sWords, &sLeft, &sTop, &sRight, &sBottom );
   else if ( direction == Page::NextResult )
     return textPage->findText( u.data(), u.size(),
-           gFalse, gTrue, gTrue, gFalse, sCase, gFalse, sWords, &sLeft, &sTop, &sRight, &sBottom );
+           false, true, true, false, sCase, false, sWords, &sLeft, &sTop, &sRight, &sBottom );
   else if ( direction == Page::PreviousResult )
     return textPage->findText( u.data(), u.size(),
-           gFalse, gTrue, gTrue, gFalse, sCase, gTrue, sWords, &sLeft, &sTop, &sRight, &sBottom );
+           false, true, true, false, sCase, true, sWords, &sLeft, &sTop, &sRight, &sBottom );
 
-  return gFalse;
+  return false;
 }
 
-inline QList<QRectF> PageData::performMultipleTextSearch(TextPage* textPage, QVector<Unicode> &u, GBool sCase, GBool sWords)
+inline QList<QRectF> PageData::performMultipleTextSearch(TextPage* textPage, QVector<Unicode> &u, bool sCase, bool sWords)
 {
   QList<QRectF> results;
   double sLeft = 0.0, sTop = 0.0, sRight = 0.0, sBottom = 0.0;
 
   while(textPage->findText( u.data(), u.size(),
-        gFalse, gTrue, gTrue, gFalse, sCase, gFalse, sWords, &sLeft, &sTop, &sRight, &sBottom ))
+        false, true, true, false, sCase, false, sWords, &sLeft, &sTop, &sRight, &sBottom ))
   {
       QRectF result;
 
@@ -427,7 +453,7 @@ static auto annotDisplayDecideCbk = [](Annot *annot, void *user_data)
 
 // A nullptr, but with the type of a function pointer
 // Needed to make the ternary operator happy.
-static GBool (*nullAnnotCallBack)(Annot *annot, void *user_data) = nullptr;
+static bool (*nullAnnotCallBack)(Annot *annot, void *user_data) = nullptr;
 
 static auto shouldAbortRenderInternalCallback = [](void *user_data)
 {
@@ -443,7 +469,7 @@ static auto shouldAbortExtractionInternalCallback = [](void *user_data)
 
 // A nullptr, but with the type of a function pointer
 // Needed to make the ternary operator happy.
-static GBool (*nullAbortCallBack)(void *user_data) = nullptr;
+static bool (*nullAbortCallBack)(void *user_data) = nullptr;
 
 static bool renderToArthur(QImageDumpingArthurOutputDev *arthur_output, QPainter *painter, PageData *page, double xres, double yres, int x, int y, int w, int h, Page::Rotation rotate, Page::PainterFlags flags)
 {
@@ -456,9 +482,9 @@ static bool renderToArthur(QImageDumpingArthurOutputDev *arthur_output, QPainter
     painter->setRenderHint(QPainter::TextAntialiasing);
   painter->translate(x == -1 ? 0 : -x, y == -1 ? 0 : -y);
 
-  arthur_output->startDoc(page->parentDoc->doc->getXRef());
+  arthur_output->startDoc(page->parentDoc->doc);
 
-  const GBool hideAnnotations = page->parentDoc->m_hints & Document::HideAnnotations;
+  const bool hideAnnotations = page->parentDoc->m_hints & Document::HideAnnotations;
 
   OutputDevCallbackHelper *abortHelper = arthur_output;
   page->parentDoc->doc->displayPageSlice(arthur_output,
@@ -475,7 +501,8 @@ static bool renderToArthur(QImageDumpingArthurOutputDev *arthur_output, QPainter
                                           h,
                                           abortHelper->shouldAbortRenderCallback ? shouldAbortRenderInternalCallback : nullAbortCallBack,
                                           abortHelper,
-                                          (hideAnnotations) ? annotDisplayDecideCbk : nullAnnotCallBack);
+                                          (hideAnnotations) ? annotDisplayDecideCbk : nullAnnotCallBack,
+                                          nullptr, true);
   if (savePainter)
     painter->restore();
   return true;
@@ -501,9 +528,9 @@ QImage Page::renderToImage(double xres, double yres, int x, int y, int w, int h,
     {
 #if defined(HAVE_SPLASH)
       SplashColor bgColor;
-      GBool overprintPreview = gFalse;
+      bool overprintPreview = false;
 #ifdef SPLASH_CMYK
-      overprintPreview = m_page->parentDoc->m_hints & Document::OverprintPreview ? gTrue : gFalse;
+      overprintPreview = m_page->parentDoc->m_hints & Document::OverprintPreview ? true : false;
       if (overprintPreview)
       {
         Guchar c, m, y, k;
@@ -547,30 +574,30 @@ QImage Page::renderToImage(double xres, double yres, int x, int y, int w, int h,
 
       Qt5SplashOutputDev splash_output(
                   colorMode, 4,
-                  gFalse,
+                  false,
                   ignorePaperColor,
                   ignorePaperColor ? nullptr : bgColor,
-                  gTrue,
+                  true,
                   thinLineMode,
                   overprintPreview);
 
       splash_output.setCallbacks(partialUpdateCallback, shouldDoPartialUpdateCallback, shouldAbortRenderCallback, payload);
 
-      splash_output.setFontAntialias(m_page->parentDoc->m_hints & Document::TextAntialiasing ? gTrue : gFalse);
-      splash_output.setVectorAntialias(m_page->parentDoc->m_hints & Document::Antialiasing ? gTrue : gFalse);
-      splash_output.setFreeTypeHinting(m_page->parentDoc->m_hints & Document::TextHinting ? gTrue : gFalse,
-                                        m_page->parentDoc->m_hints & Document::TextSlightHinting ? gTrue : gFalse);
+      splash_output.setFontAntialias(m_page->parentDoc->m_hints & Document::TextAntialiasing ? true : false);
+      splash_output.setVectorAntialias(m_page->parentDoc->m_hints & Document::Antialiasing ? true : false);
+      splash_output.setFreeTypeHinting(m_page->parentDoc->m_hints & Document::TextHinting ? true : false,
+                                        m_page->parentDoc->m_hints & Document::TextSlightHinting ? true : false);
 
       splash_output.startDoc(m_page->parentDoc->doc);
 
-      const GBool hideAnnotations = m_page->parentDoc->m_hints & Document::HideAnnotations;
+      const bool hideAnnotations = m_page->parentDoc->m_hints & Document::HideAnnotations;
 
       OutputDevCallbackHelper *abortHelper = &splash_output;
       m_page->parentDoc->doc->displayPageSlice(&splash_output, m_page->index + 1, xres, yres,
                                                rotation, false, true, false, x, y, w, h,
                                                shouldAbortRenderCallback ? shouldAbortRenderInternalCallback : nullAbortCallBack, abortHelper,
                                                (hideAnnotations) ? annotDisplayDecideCbk : nullAnnotCallBack,
-                                               nullptr, gTrue);
+                                               nullptr, true);
 
       img = splash_output.getXBGRImage( true /* takeImageData */);
 #endif
@@ -628,7 +655,7 @@ QImage Page::thumbnail() const
   int w = 0;
   int h = 0;
   int rowstride = 0;
-  GBool r = m_page->page->loadThumb(&data, &w, &h, &rowstride);
+  bool r = m_page->page->loadThumb(&data, &w, &h, &rowstride);
   QImage ret;
   if (r)
   {
@@ -644,17 +671,16 @@ QString Page::text(const QRectF &r, TextLayout textLayout) const
 {
   TextOutputDev *output_dev;
   GooString *s;
-  PDFRectangle *rect;
   QString result;
   
-  const GBool rawOrder = textLayout == RawOrderLayout;
-  output_dev = new TextOutputDev(nullptr, gFalse, 0, rawOrder, gFalse);
+  const bool rawOrder = textLayout == RawOrderLayout;
+  output_dev = new TextOutputDev(nullptr, false, 0, rawOrder, false);
   m_page->parentDoc->doc->displayPageSlice(output_dev, m_page->index + 1, 72, 72,
       0, false, true, false, -1, -1, -1, -1,
-      nullptr, nullptr, nullptr, nullptr, gTrue);
+      nullptr, nullptr, nullptr, nullptr, true);
   if (r.isNull())
   {
-    rect = m_page->page->getCropBox();
+    const PDFRectangle *rect = m_page->page->getCropBox();
     s = output_dev->getText(rect->x1, rect->y1, rect->x2, rect->y2);
   }
   else
@@ -676,12 +702,12 @@ QString Page::text(const QRectF &r) const
 
 bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRight, double &sBottom, SearchDirection direction, SearchMode caseSensitive, Rotation rotate) const
 {
-  const GBool sCase = caseSensitive == Page::CaseSensitive ? gTrue : gFalse;
+  const bool sCase = caseSensitive == Page::CaseSensitive ? true : false;
 
   QVector<Unicode> u;
   TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-  const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, gFalse);
+  const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, false);
 
   textPage->decRefCnt();
 
@@ -690,8 +716,8 @@ bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRig
 
 bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRight, double &sBottom, SearchDirection direction, SearchFlags flags, Rotation rotate) const
 {
-  const GBool sCase = flags.testFlag(IgnoreCase) ? gFalse : gTrue;
-  const GBool sWords = flags.testFlag(WholeWords) ? gTrue : gFalse;
+  const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
+  const bool sWords = flags.testFlag(WholeWords) ? true : false;
 
   QVector<Unicode> u;
   TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
@@ -705,12 +731,12 @@ bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRig
 
 QList<QRectF> Page::search(const QString &text, SearchMode caseSensitive, Rotation rotate) const
 {
-  const GBool sCase = caseSensitive == Page::CaseSensitive ? gTrue : gFalse;
+  const bool sCase = caseSensitive == Page::CaseSensitive ? true : false;
 
   QVector<Unicode> u;
   TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-  const QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, gFalse);
+  const QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, false);
   
   textPage->decRefCnt();
 
@@ -719,8 +745,8 @@ QList<QRectF> Page::search(const QString &text, SearchMode caseSensitive, Rotati
 
 QList<QRectF> Page::search(const QString &text, SearchFlags flags, Rotation rotate) const
 {
-  const GBool sCase = flags.testFlag(IgnoreCase) ? gFalse : gTrue;
-  const GBool sWords = flags.testFlag(WholeWords) ? gTrue : gFalse;
+  const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
+  const bool sWords = flags.testFlag(WholeWords) ? true : false;
 
   QVector<Unicode> u;
   TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
@@ -743,7 +769,7 @@ QList<TextBox*> Page::textList(Rotation rotate, ShouldAbortQueryFunc shouldAbort
   
   QList<TextBox*> output_list;
   
-  output_dev = new TextOutputDev(nullptr, gFalse, 0, gFalse, gFalse);
+  output_dev = new TextOutputDev(nullptr, false, 0, false, false);
   
   int rotation = (int)rotate * 90;
 
@@ -751,7 +777,7 @@ QList<TextBox*> Page::textList(Rotation rotate, ShouldAbortQueryFunc shouldAbort
   m_page->parentDoc->doc->displayPageSlice(output_dev, m_page->index + 1, 72, 72,
       rotation, false, false, false, -1, -1, -1, -1,
       shouldAbortExtractionCallback ? shouldAbortExtractionInternalCallback : nullAbortCallBack, &abortHelper,
-      nullptr, nullptr, gTrue);
+      nullptr, nullptr, true);
 
   TextWordList *word_list = output_dev->makeWordList();
   
@@ -772,7 +798,7 @@ QList<TextBox*> Page::textList(Rotation rotate, ShouldAbortQueryFunc shouldAbort
     word->getBBox(&xMin, &yMin, &xMax, &yMax);
     
     TextBox* text_box = new TextBox(string, QRectF(xMin, yMin, xMax-xMin, yMax-yMin));
-    text_box->m_data->hasSpaceAfter = word->hasSpaceAfter() == gTrue;
+    text_box->m_data->hasSpaceAfter = word->hasSpaceAfter() == true;
     text_box->m_data->charBBoxes.reserve(word->getLength());
     for (int j = 0; j < word->getLength(); ++j)
     {
@@ -867,7 +893,7 @@ Page::Orientation Page::orientation() const
 
 void Page::defaultCTM(double *CTM, double dpiX, double dpiY, int rotate, bool upsideDown)
 {
-  m_page->page->getDefaultCTM(CTM, dpiX, dpiY, rotate, gFalse, upsideDown);
+  m_page->page->getDefaultCTM(CTM, dpiX, dpiY, rotate, false, upsideDown);
 }
 
 QList<Link*> Page::links() const
@@ -961,5 +987,9 @@ QString Page::label() const
   return UnicodeParsedString(&goo);
 }
 
+int Page::index() const
+{
+  return m_page->index;
+}
 
 }
