@@ -14,7 +14,7 @@ void TestLexer::testNumbers()
 {
     char data[] = "0 1 -1 2147483647 -2147483647 2147483648 -2147483648 4294967297 -2147483649 0.1 1.1 -1.1 2147483647.1 -2147483647.1 2147483648.1 -2147483648.1 4294967297.1 -2147483649.1 9223372036854775807 18446744073709551615";
     MemStream *stream = new MemStream(data, 0, strlen(data), Object(objNull));
-    Lexer *lexer = new Lexer(NULL, stream);
+    Lexer *lexer = new Lexer(nullptr, stream);
     QVERIFY( lexer );
     
     Object obj;
