@@ -18,6 +18,7 @@
 // Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2018 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -26,10 +27,6 @@
 
 #include <config.h>
 
-#ifdef USE_GCC_PRAGMAS
-#pragma implementation
-#endif
-
 #include <ft2build.h>
 #include FT_OUTLINE_H
 #include FT_SIZES_H
@@ -58,7 +55,7 @@ static int glyphPathCubicTo(const FT_Vector *ctrl1, const FT_Vector *ctrl2,
 //------------------------------------------------------------------------
 
 SplashFTFont::SplashFTFont(SplashFTFontFile *fontFileA, SplashCoord *matA,
-			   SplashCoord *textMatA):
+			   const SplashCoord *textMatA):
   SplashFont(fontFileA, matA, textMatA, fontFileA->engine->aa), 
   textScale(0),
   enableFreeTypeHinting(fontFileA->engine->enableFreeTypeHinting),
@@ -237,12 +234,12 @@ SplashFTFont::SplashFTFont(SplashFTFontFile *fontFileA, SplashCoord *matA,
 SplashFTFont::~SplashFTFont() {
 }
 
-GBool SplashFTFont::getGlyph(int c, int xFrac, int yFrac,
+bool SplashFTFont::getGlyph(int c, int xFrac, int yFrac,
 			     SplashGlyphBitmap *bitmap, int x0, int y0, SplashClip *clip, SplashClipResult *clipRes) {
   return SplashFont::getGlyph(c, xFrac, 0, bitmap, x0, y0, clip, clipRes);
 }
 
-static FT_Int32 getFTLoadFlags(GBool type1, GBool trueType, GBool aa, GBool enableFreeTypeHinting, GBool enableSlightHinting)
+static FT_Int32 getFTLoadFlags(bool type1, bool trueType, bool aa, bool enableFreeTypeHinting, bool enableSlightHinting)
 {
   int ret = FT_LOAD_DEFAULT;
   if (aa)
@@ -271,7 +268,7 @@ static FT_Int32 getFTLoadFlags(GBool type1, GBool trueType, GBool aa, GBool enab
   return ret;
 }
 
-GBool SplashFTFont::makeGlyph(int c, int xFrac, int yFrac,
+bool SplashFTFont::makeGlyph(int c, int xFrac, int yFrac,
 			      SplashGlyphBitmap *bitmap, int x0, int y0, SplashClip *clip, SplashClipResult *clipRes) {
   SplashFTFontFile *ff;
   FT_Vector offset;
@@ -282,7 +279,7 @@ GBool SplashFTFont::makeGlyph(int c, int xFrac, int yFrac,
   int i;
 
   if (unlikely(!isOk)) {
-    return gFalse;
+    return false;
   }
 
   ff = (SplashFTFontFile *)fontFile;
@@ -300,7 +297,7 @@ GBool SplashFTFont::makeGlyph(int c, int xFrac, int yFrac,
   }
 
   if (FT_Load_Glyph(ff->face, gid, getFTLoadFlags(ff->type1, ff->trueType, aa, enableFreeTypeHinting, enableSlightHinting))) {
-    return gFalse;
+    return false;
   }
 
   // prelimirary values based on FT_Outline_Get_CBox
@@ -317,19 +314,19 @@ GBool SplashFTFont::makeGlyph(int c, int xFrac, int yFrac,
                             x0 - bitmap->x + bitmap->w,
                             y0 - bitmap->y + bitmap->h);
   if (*clipRes == splashClipAllOutside) {
-    bitmap->freeData = gFalse;
-    return gTrue;
+    bitmap->freeData = false;
+    return true;
   }
 
   if (FT_Render_Glyph(slot, aa ? ft_render_mode_normal
 		               : ft_render_mode_mono)) {
-    return gFalse;
+    return false;
   }
 
   if (slot->bitmap.width == 0 || slot->bitmap.rows == 0) {
     // this can happen if (a) the glyph is really tiny or (b) the
     // metrics in the TrueType file are broken
-    return gFalse;
+    return false;
   }
 
   bitmap->x = -slot->bitmap_left;
@@ -344,16 +341,16 @@ GBool SplashFTFont::makeGlyph(int c, int xFrac, int yFrac,
   }
   bitmap->data = (Guchar *)gmallocn_checkoverflow(rowSize, bitmap->h);
   if (!bitmap->data) {
-    return gFalse;
+    return false;
   }
-  bitmap->freeData = gTrue;
+  bitmap->freeData = true;
   for (i = 0, p = bitmap->data, q = slot->bitmap.buffer;
        i < bitmap->h;
        ++i, p += rowSize, q += slot->bitmap.pitch) {
     memcpy(p, q, rowSize);
   }
 
-  return gTrue;
+  return true;
 }
 
 double SplashFTFont::getGlyphAdvance(int c)
@@ -395,7 +392,7 @@ double SplashFTFont::getGlyphAdvance(int c)
 struct SplashFTFontPath {
   SplashPath *path;
   SplashCoord textScale;
-  GBool needClose;
+  bool needClose;
 };
 
 SplashPath *SplashFTFont::getGlyphPath(int c) {
@@ -443,7 +440,7 @@ SplashPath *SplashFTFont::getGlyphPath(int c) {
   }
   path.path = new SplashPath();
   path.textScale = textScale;
-  path.needClose = gFalse;
+  path.needClose = false;
   FT_Outline_Decompose(&((FT_OutlineGlyph)glyph)->outline,
 		       &outlineFuncs, &path);
   if (path.needClose) {
@@ -458,7 +455,7 @@ static int glyphPathMoveTo(const FT_Vector *pt, void *path) {
 
   if (p->needClose) {
     p->path->close();
-    p->needClose = gFalse;
+    p->needClose = false;
   }
   p->path->moveTo((SplashCoord)pt->x * p->textScale / 64.0,
 		  (SplashCoord)pt->y * p->textScale / 64.0);
@@ -470,7 +467,7 @@ static int glyphPathLineTo(const FT_Vector *pt, void *path) {
 
   p->path->lineTo((SplashCoord)pt->x * p->textScale / 64.0,
 		  (SplashCoord)pt->y * p->textScale / 64.0);
-  p->needClose = gTrue;
+  p->needClose = true;
   return 0;
 }
 
@@ -509,7 +506,7 @@ static int glyphPathConicTo(const FT_Vector *ctrl, const FT_Vector *pt,
   y2 = (SplashCoord)(1.0 / 3.0) * ((SplashCoord)2 * yc + y3);
 
   p->path->curveTo(x1, y1, x2, y2, x3, y3);
-  p->needClose = gTrue;
+  p->needClose = true;
   return 0;
 }
 
@@ -523,6 +520,6 @@ static int glyphPathCubicTo(const FT_Vector *ctrl1, const FT_Vector *ctrl2,
 		   (SplashCoord)ctrl2->y * p->textScale / 64.0,
 		   (SplashCoord)pt->x * p->textScale / 64.0,
 		   (SplashCoord)pt->y * p->textScale / 64.0);
-  p->needClose = gTrue;
+  p->needClose = true;
   return 0;
 }
