@@ -42,16 +42,13 @@
 // Copyright (C) 2017 Caolán McNamara <caolanm@redhat.com>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Thibaut Brard <thibaut.brard@gmail.com>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
 //
 //========================================================================
 
-#ifdef __GNUC__
-#pragma implementation
-#endif
-
 #include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -102,26 +99,26 @@ public:
 // returns true if x is closer to y than x is to z
 static inline bool IS_CLOSER(float x, float y, float z) { return fabs((x)-(y)) < fabs((x)-(z)); }
 
-extern GBool complexMode;
-extern GBool singleHtml;
-extern GBool ignore;
-extern GBool printCommands;
-extern GBool printHtml;
-extern GBool noframes;
-extern GBool stout;
-extern GBool xml;
-extern GBool noRoundedCoordinates;
-extern GBool showHidden;
-extern GBool noMerge;
+extern bool complexMode;
+extern bool singleHtml;
+extern bool ignore;
+extern bool printCommands;
+extern bool printHtml;
+extern bool noframes;
+extern bool stout;
+extern bool xml;
+extern bool noRoundedCoordinates;
+extern bool showHidden;
+extern bool noMerge;
 
 extern double wordBreakThreshold;
 
-static GBool debug = gFalse;
+static bool debug = false;
 static GooString *gstr_buff0 = nullptr; // a workspace in which I format strings
 
 static GooString* basename(GooString* str){
   
-  char *p=str->getCString();
+  const char *p=str->getCString();
   int len=str->getLength();
   for (int i=len-1;i>=0;i--)
     if (*(p+i)==SLASH) 
@@ -279,7 +276,7 @@ void HtmlString::endString()
 // HtmlPage
 //------------------------------------------------------------------------
 
-HtmlPage::HtmlPage(GBool rawOrder, char *imgExtVal) {
+HtmlPage::HtmlPage(bool rawOrder, const char *imgExtVal) {
   this->rawOrder = rawOrder;
   curStr = nullptr;
   yxStrings = nullptr;
@@ -302,13 +299,12 @@ HtmlPage::~HtmlPage() {
   delete fonts;
   delete links;
   delete imgExt;
-  deleteGooList(imgList, HtmlImage);
+  deleteGooList<HtmlImage>(imgList);
 }
 
 void HtmlPage::updateFont(GfxState *state) {
   GfxFont *font;
-  double *fm;
-  char *name;
+  const char *name;
   int code;
   double w;
   
@@ -334,7 +330,7 @@ void HtmlPage::updateFont(GfxState *state) {
 	fontSize *= w / 0.6;
       }
     }
-    fm = font->getFontMatrix();
+    const double *fm = font->getFontMatrix();
     if (fm[0] != 0) {
       fontSize *= fabs(fm[3] / fm[0]);
     }
@@ -347,26 +343,15 @@ void HtmlPage::beginString(GfxState *state, const GooString *s) {
 
 
 void HtmlPage::conv(){
-  HtmlString *tmp;
-
-  int linkIndex = 0;
-  HtmlFont* h;
-  for(tmp=yxStrings;tmp;tmp=tmp->yxNext){
-     int pos=tmp->fontpos;
-     //  printf("%d\n",pos);
-     h=fonts->Get(pos);
-
-     if (tmp->htext) delete tmp->htext; 
-     tmp->htext=HtmlFont::simple(h,tmp->text,tmp->len);
+  for(HtmlString *tmp=yxStrings;tmp;tmp=tmp->yxNext){
+     delete tmp->htext;
+     tmp->htext=HtmlFont::HtmlFilter(tmp->text,tmp->len);
 
+     int linkIndex = 0;
      if (links->inLink(tmp->xMin,tmp->yMin,tmp->xMax,tmp->yMax, linkIndex)){
        tmp->link = links->getLink(linkIndex);
-       /*GooString *t=tmp->htext;
-       tmp->htext=links->getLink(k)->Link(tmp->htext);
-       delete t;*/
      }
   }
-
 }
 
 
@@ -383,7 +368,7 @@ void HtmlPage::addChar(GfxState *state, double x, double y,
   //if ((UnicodeMap::getDirection(u[0]) != curStr->dir) || 
   // XXX
   if (debug) {
-    double *text_mat = state->getTextMat();
+    const double *text_mat = state->getTextMat();
     // rotation is (cos q, sin q, -sin q, cos q, 0, 0)
     // sin q is zero iff there is no rotation, or 180 deg. rotation;
     // for 180 rotation, cos q will be negative
@@ -482,7 +467,7 @@ static const char *strrstr( const char *s, const char *ss )
   return p;
 }
 
-static void CloseTags( GooString *htext, GBool &finish_a, GBool &finish_italic, GBool &finish_bold )
+static void CloseTags( GooString *htext, bool &finish_a, bool &finish_italic, bool &finish_bold )
 {
   const char *last_italic = finish_italic && ( finish_bold   || finish_a    ) ? strrstr( htext->getCString(), "<i>" ) : nullptr;
   const char *last_bold   = finish_bold   && ( finish_italic || finish_a    ) ? strrstr( htext->getCString(), "<b>" ) : nullptr;
@@ -510,7 +495,7 @@ void HtmlPage::coalesce() {
   HtmlString *str1, *str2;
   HtmlFont *hfont1, *hfont2;
   double space, horSpace, vertSpace, vertOverlap;
-  GBool addSpace, addLineBreak;
+  bool addSpace, addLineBreak;
   int n, i;
   double curX, curY;
 
@@ -534,12 +519,12 @@ void HtmlPage::coalesce() {
   if( !complexMode )
   {	/* if not in complex mode get rid of duplicate strings */
 	HtmlString *str3;
-	GBool found;
+	bool found;
   	while (str1)
 	{
 		double size = str1->yMax - str1->yMin;
 		double xLimit = str1->xMin + size * 0.2;
-		found = gFalse;
+		found = false;
 		for (str2 = str1, str3 = str1->yxNext;
 			str3 && str3->xMin < xLimit;
 			str2 = str3, str3 = str2->yxNext)
@@ -550,7 +535,7 @@ void HtmlPage::coalesce() {
 				fabs(str3->yMax - str1->yMax) < size * 0.2 &&
 				fabs(str3->xMax - str1->xMax) < size * 0.2)
 			{
-				found = gTrue;
+				found = true;
 				//printf("found duplicate!\n");
 				break;
 			}
@@ -681,9 +666,9 @@ void HtmlPage::coalesce() {
       HtmlLink *hlink1 = str1->getLink();
       HtmlLink *hlink2 = str2->getLink();
       bool switch_links = !hlink1 || !hlink2 || !hlink1->isEqualDest(*hlink2);
-      GBool finish_a = switch_links && hlink1 != nullptr;
-      GBool finish_italic = hfont1->isItalic() && ( !hfont2->isItalic() || finish_a );
-      GBool finish_bold   = hfont1->isBold()   && ( !hfont2->isBold()   || finish_a || finish_italic );
+      bool finish_a = switch_links && hlink1 != nullptr;
+      bool finish_italic = hfont1->isItalic() && ( !hfont2->isItalic() || finish_a );
+      bool finish_bold   = hfont1->isBold()   && ( !hfont2->isBold()   || finish_a || finish_italic );
       CloseTags( str1->htext, finish_a, finish_italic, finish_bold );
       if( switch_links && hlink2 != nullptr ) {
         GooString *ls = hlink2->getLinkStart();
@@ -710,9 +695,9 @@ void HtmlPage::coalesce() {
       delete str2;
     } else { // keep strings separate
 //      printf("no\n"); 
-      GBool finish_a = str1->getLink() != nullptr;
-      GBool finish_bold   = hfont1->isBold();
-      GBool finish_italic = hfont1->isItalic();
+      bool finish_a = str1->getLink() != nullptr;
+      bool finish_bold   = hfont1->isBold();
+      bool finish_italic = hfont1->isItalic();
       CloseTags( str1->htext, finish_a, finish_italic, finish_bold );
      
       str1->xMin = curX; str1->yMin = curY; 
@@ -732,9 +717,9 @@ void HtmlPage::coalesce() {
   }
   str1->xMin = curX; str1->yMin = curY;
 
-  GBool finish_bold   = hfont1->isBold();
-  GBool finish_italic = hfont1->isItalic();
-  GBool finish_a = str1->getLink() != nullptr;
+  bool finish_bold   = hfont1->isBold();
+  bool finish_italic = hfont1->isItalic();
+  bool finish_a = str1->getLink() != nullptr;
   CloseTags( str1->htext, finish_a, finish_italic, finish_bold );
 
 #if 0 //~ for debugging
@@ -758,10 +743,9 @@ void HtmlPage::dumpAsXML(FILE* f,int page){
     fprintf(f,"\t%s\n",fontCSStyle->getCString());
     delete fontCSStyle;
   }
-  
-  int listlen=imgList->getLength();
-  for (int i = 0; i < listlen; i++) {
-    HtmlImage *img = (HtmlImage*)imgList->del(0);
+
+  for (auto ptr : *imgList) {
+    auto img = static_cast<HtmlImage *>(ptr);
     if (!noRoundedCoordinates) {
       fprintf(f, "<image top=\"%d\" left=\"%d\" ", xoutRound(img->yMin), xoutRound(img->xMin));
       fprintf(f, "width=\"%d\" height=\"%d\" ", xoutRound(img->xMax - img->xMin), xoutRound(img->yMax - img->yMin));
@@ -773,6 +757,7 @@ void HtmlPage::dumpAsXML(FILE* f,int page){
     fprintf(f,"src=\"%s\"/>\n",img->fName->getCString());
     delete img;
   }
+  imgList->clear();
 
   for(HtmlString *tmp=yxStrings;tmp;tmp=tmp->yxNext){
     if (tmp->htext){
@@ -953,9 +938,8 @@ void HtmlPage::dump(FILE *f, int pageNum)
   {
     fprintf(f,"<a name=%d></a>",pageNum);
     // Loop over the list of image names on this page
-    int listlen=imgList->getLength();
-    for (int i = 0; i < listlen; i++) {
-      HtmlImage *img = (HtmlImage*)imgList->del(0);
+    for (auto ptr : *imgList) {
+      auto img = static_cast<HtmlImage *>(ptr);
 
       // see printCSS() for class names
       const char *styles[4] = { "", " class=\"xflip\"", " class=\"yflip\"", " class=\"xyflip\"" };
@@ -966,6 +950,7 @@ void HtmlPage::dump(FILE *f, int pageNum)
       fprintf(f,"<img%s src=\"%s\"/><br/>\n",styles[style_index],img->fName->getCString());
       delete img;
     }
+    imgList->clear();
 
     GooString* str;
     for(HtmlString *tmp=yxStrings;tmp;tmp=tmp->yxNext){
@@ -1014,13 +999,13 @@ void HtmlPage::clear() {
 
 }
 
-void HtmlPage::setDocName(char *fname){
+void HtmlPage::setDocName(const char *fname){
   DocName=new GooString(fname);
 }
 
 void HtmlPage::addImage(GooString *fname, GfxState *state) {
   HtmlImage *img = new HtmlImage(fname, state);
-  imgList->append(img);
+  imgList->push_back(img);
 }
 
 //------------------------------------------------------------------------
@@ -1109,32 +1094,32 @@ void HtmlOutputDev::doFrame(int firstPage){
   fclose(fContentsFrame);  
 }
 
-HtmlOutputDev::HtmlOutputDev(Catalog *catalogA, char *fileName, char *title, 
-	char *author, char *keywords, char *subject, char *date,
-	char *extension,
-	GBool rawOrder, int firstPage, GBool outline) 
+HtmlOutputDev::HtmlOutputDev(Catalog *catalogA, const char *fileName, const char *title,
+	const char *author, const char *keywords, const char *subject, const char *date,
+	const char *extension,
+	bool rawOrder, int firstPage, bool outline) 
 {
   catalog = catalogA;
   fContentsFrame = nullptr;
   docTitle = new GooString(title);
   pages = nullptr;
-  dumpJPEG=gTrue;
-  //write = gTrue;
+  dumpJPEG=true;
+  //write = true;
   this->rawOrder = rawOrder;
   this->doOutline = outline;
-  ok = gFalse;
+  ok = false;
   //this->firstPage = firstPage;
   //pageNum=firstPage;
   // open file
-  needClose = gFalse;
+  needClose = false;
   pages = new HtmlPage(rawOrder, extension);
   
   glMetaVars = new GooList();
-  glMetaVars->append(new HtmlMetaVar("generator", "pdftohtml 0.36"));  
-  if( author ) glMetaVars->append(new HtmlMetaVar("author", author));  
-  if( keywords ) glMetaVars->append(new HtmlMetaVar("keywords", keywords));  
-  if( date ) glMetaVars->append(new HtmlMetaVar("date", date));  
-  if( subject ) glMetaVars->append(new HtmlMetaVar("subject", subject));
+  glMetaVars->push_back(new HtmlMetaVar("generator", "pdftohtml 0.36"));
+  if( author ) glMetaVars->push_back(new HtmlMetaVar("author", author));
+  if( keywords ) glMetaVars->push_back(new HtmlMetaVar("keywords", keywords));
+  if( date ) glMetaVars->push_back(new HtmlMetaVar("date", date));
+  if( subject ) glMetaVars->push_back(new HtmlMetaVar("subject", subject));
  
   maxPageWidth = 0;
   maxPageHeight = 0;
@@ -1222,16 +1207,14 @@ HtmlOutputDev::HtmlOutputDev(Catalog *catalogA, char *fileName, char *title,
     }
     delete htmlEncoding;
   }
-  ok = gTrue; 
+  ok = true; 
 }
 
 HtmlOutputDev::~HtmlOutputDev() {
-    HtmlFont::clear(); 
-    
     delete Docname;
     delete docTitle;
 
-    deleteGooList(glMetaVars, HtmlMetaVar);
+    deleteGooList<HtmlMetaVar>(glMetaVars);
 
     if (fContentsFrame){
       fputs("</body>\n</html>\n",fContentsFrame);  
@@ -1256,7 +1239,7 @@ void HtmlOutputDev::startPage(int pageNum, GfxState *state, XRef *xref) {
 #if 0
   if (mode&&!xml){
     if (write){
-      write=gFalse;
+      write=false;
       GooString* fname=Dirname(Docname);
       fname->append("image.log");
       if((tin=fopen(getFileNameFromPath(fname->getCString(),fname->getLength()),"w"))==NULL){
@@ -1368,7 +1351,7 @@ void HtmlOutputDev::drawJpegImage(GfxState *state, Stream *str)
 }
 
 void HtmlOutputDev::drawPngImage(GfxState *state, Stream *str, int width, int height,
-                                 GfxImageColorMap *colorMap, GBool isMask)
+                                 GfxImageColorMap *colorMap, bool isMask)
 {
 #ifdef ENABLE_LIBPNG
   FILE *f1;
@@ -1506,8 +1489,8 @@ GooString *HtmlOutputDev::createImageFileName(const char *ext)
 }
 
 void HtmlOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
-				  int width, int height, GBool invert,
-				  GBool interpolate, GBool inlineImg) {
+				  int width, int height, bool invert,
+				  bool interpolate, bool inlineImg) {
 
   if (ignore||(complexMode && !xml)) {
     OutputDev::drawImageMask(state, ref, str, width, height, invert, interpolate, inlineImg);
@@ -1520,7 +1503,7 @@ void HtmlOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
   }
   else {
 #ifdef ENABLE_LIBPNG
-    drawPngImage(state, str, width, height, nullptr, gTrue);
+    drawPngImage(state, str, width, height, nullptr, true);
 #else
     OutputDev::drawImageMask(state, ref, str, width, height, invert, interpolate, inlineImg);
 #endif
@@ -1529,7 +1512,7 @@ void HtmlOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
 
 void HtmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
 			      int width, int height, GfxImageColorMap *colorMap,
-			      GBool interpolate, int *maskColors, GBool inlineImg) {
+			      bool interpolate, int *maskColors, bool inlineImg) {
 
   if (ignore||(complexMode && !xml)) {
     OutputDev::drawImage(state, ref, str, width, height, colorMap, interpolate,
@@ -1573,7 +1556,6 @@ void HtmlOutputDev::doProcessLink(AnnotLink* link){
 }
 
 GooString* HtmlOutputDev::getLinkDest(AnnotLink *link){
-  char *p;
   if (!link->getAction())
     return new GooString();
   switch(link->getAction()->getKind()) 
@@ -1651,7 +1633,7 @@ GooString* HtmlOutputDev::getLinkDest(AnnotLink *link){
 
 	      if (printCommands) printf(" link to page %d ",page);
 	      if (printHtml){
-		  p=file->getCString()+file->getLength()-4;
+		  const char *p=file->getCString()+file->getLength()-4;
 		  if (!strcmp(p, ".pdf") || !strcmp(p, ".PDF")){
 		      file->del(file->getLength()-4,4);
 		      file->append(".html");
@@ -1676,7 +1658,7 @@ GooString* HtmlOutputDev::getLinkDest(AnnotLink *link){
 	  if (printHtml) {
 	      LinkLaunch *ha=(LinkLaunch *) link->getAction();
 	      GooString* file=new GooString(ha->getFileName()->getCString());
-	      p=file->getCString()+file->getLength()-4;
+	      const char *p=file->getCString()+file->getLength()-4;
 	      if (!strcmp(p, ".pdf") || !strcmp(p, ".PDF")){
 		  file->del(file->getLength()-4,4);
 		  file->append(".html");
@@ -1705,24 +1687,21 @@ void HtmlOutputDev::dumpMetaVars(FILE *file)
   }
 }
 
-GBool HtmlOutputDev::dumpDocOutline(PDFDoc* doc)
+bool HtmlOutputDev::dumpDocOutline(PDFDoc* doc)
 { 
-#ifdef DISABLE_OUTLINE
-	return gFalse;
-#else
 	FILE * output = nullptr;
-	GBool bClose = gFalse;
+	bool bClose = false;
 
 	if (!ok)
-                return gFalse;
+                return false;
   
 	Outline *outline = doc->getOutline();
 	if (!outline)
-		return gFalse;
+		return false;
 
 	const GooList *outlines = outline->getItems();
 	if (!outlines)
-		return gFalse;
+		return false;
   
 	if (!complexMode || xml)
   	{
@@ -1742,8 +1721,8 @@ GBool HtmlOutputDev::dumpDocOutline(PDFDoc* doc)
 			output = fopen(str->getCString(), "w");
 			delete str;
 			if (output == nullptr)
-				return gFalse;
-			bClose = gTrue;
+				return false;
+			bClose = true;
 
 			GooString *htmlEncoding =
 				HtmlOutputDev::mapEncodingToHtml(globalParams->getTextEncodingName());
@@ -1761,7 +1740,7 @@ GBool HtmlOutputDev::dumpDocOutline(PDFDoc* doc)
  
 	if (!xml)
 	{
-		GBool done = newHtmlOutlineLevel(output, outlines);
+		bool done = newHtmlOutlineLevel(output, outlines);
 		if (done && !complexMode)
 			fputs("<hr/>\n", output);
 	
@@ -1774,16 +1753,12 @@ GBool HtmlOutputDev::dumpDocOutline(PDFDoc* doc)
 	else
 		newXmlOutlineLevel(output, outlines);
 
-	return gTrue;
-#endif
+	return true;
 }
 
-GBool HtmlOutputDev::newHtmlOutlineLevel(FILE *output, const GooList *outlines, int level)
+bool HtmlOutputDev::newHtmlOutlineLevel(FILE *output, const GooList *outlines, int level)
 {
-#ifdef DISABLE_OUTLINE
-	return gFalse;
-#else
-	GBool atLeastOne = gFalse;
+	bool atLeastOne = false;
 
 	if (level == 1)
 	{
@@ -1833,7 +1808,7 @@ GBool HtmlOutputDev::newHtmlOutlineLevel(FILE *output, const GooList *outlines,
 			delete linkName;
 		}
 		delete titleStr;
-		atLeastOne = gTrue;
+		atLeastOne = true;
 
 		item->open();
 		if (item->hasKids() && item->getKids())
@@ -1847,12 +1822,10 @@ GBool HtmlOutputDev::newHtmlOutlineLevel(FILE *output, const GooList *outlines,
 	fputs("</ul>\n",output);
 
 	return atLeastOne;
-#endif
 }
 
 void HtmlOutputDev::newXmlOutlineLevel(FILE *output, const GooList *outlines)
 {
-#ifndef DISABLE_OUTLINE
     fputs("<outline>\n", output);
 
     for (int i = 0; i < outlines->getLength(); i++)
@@ -1881,10 +1854,8 @@ void HtmlOutputDev::newXmlOutlineLevel(FILE *output, const GooList *outlines)
     }    
 
     fputs("</outline>\n", output);
-#endif
 }
 
-#ifndef DISABLE_OUTLINE
 int HtmlOutputDev::getOutlinePageNum(OutlineItem *item)
 {
     const LinkAction *action   = item->getAction();
@@ -1918,4 +1889,3 @@ int HtmlOutputDev::getOutlinePageNum(OutlineItem *item)
     delete linkdest;
     return pagenum;
 }
-#endif
