@@ -4,7 +4,7 @@
 //
 // Copyright (C) 2014 Rodrigo Rivas Costa <rodrigorivascosta@gmail.com>
 // Copyright (C) 2014, 2017 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2017 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2017, 2018 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -18,6 +18,7 @@
 
 #include "parseargs.h"
 #include "pdftocairo-win32.h"
+#include "Win32Console.h"
 
 #include <dlgs.h>
 #include <commctrl.h>
@@ -26,8 +27,8 @@
 #include <winspool.h>
 
 static HDC hdc;
-static HGLOBAL hDevmode = 0;
-static HGLOBAL hDevnames = 0;
+static HGLOBAL hDevmode = nullptr;
+static HGLOBAL hDevnames = nullptr;
 static DEVMODEA *devmode;
 static char *printerName;
 
@@ -52,7 +53,7 @@ static const Win32Option win32PaperSource[] =
   {"largefmt", DMBIN_LARGEFMT},
   {"largecapacity", DMBIN_LARGECAPACITY},
   {"formsource", DMBIN_FORMSOURCE},
-  {NULL, 0}
+  {nullptr, 0}
 };
 
 static void parseSource(GooString *source)
@@ -74,7 +75,7 @@ static const Win32Option win32DuplexMode[] =
   {"off", DMDUP_SIMPLEX},
   {"short", DMDUP_HORIZONTAL},
   {"long", DMDUP_VERTICAL},
-  {NULL, 0}
+  {nullptr, 0}
 };
 
 static void parseDuplex(GooString *mode)
@@ -91,7 +92,7 @@ static void parseDuplex(GooString *mode)
   fprintf(stderr, "Warning: Unknown duplex mode \"%s\"\n", mode->getCString());
 }
 
-static void fillCommonPrinterOptions(GBool duplex)
+static void fillCommonPrinterOptions(bool duplex)
 {
   if (duplex) {
     devmode->dmDuplex = DMDUP_HORIZONTAL;
@@ -117,7 +118,7 @@ static void fillPagePrinterOptions(double w, double h)
 }
 
 
-static void fillPrinterOptions(GBool duplex, GooString *printOpt)
+static void fillPrinterOptions(bool duplex, GooString *printOpt)
 {
   //printOpt format is: <opt1>=<val1>,<opt2>=<val2>,...
   const char *nextOpt = printOpt->getCString();
@@ -234,8 +235,8 @@ enum PageScale { NONE = 0, SHRINK = 1, FIT = 2 };
 
 // used to set/get option values in printDialogHookProc
 static PageScale pageScale;
-static GBool centerPage;
-static GBool useOrigPageSize;
+static bool centerPage;
+static bool useOrigPageSize;
 
 // PrintDlg callback to customize the print dialog with additional controls.
 static UINT_PTR CALLBACK printDialogHookProc(HWND hdlg, UINT uiMsg, WPARAM wParam, LPARAM lParam)
@@ -286,7 +287,7 @@ static UINT_PTR CALLBACK printDialogHookProc(HWND hdlg, UINT uiMsg, WPARAM wPara
     // Increase dialog size
     RECT dlgRect;
     GetWindowRect(hdlg, &dlgRect);
-    SetWindowPos(hdlg, NULL,
+    SetWindowPos(hdlg, nullptr,
 		 dlgRect.left, dlgRect.top,
 		 dlgRect.right - dlgRect.left,
 		 dlgRect.bottom - dlgRect.top + interGroupSpace + groupHeight,
@@ -363,19 +364,19 @@ static UINT_PTR CALLBACK printDialogHookProc(HWND hdlg, UINT uiMsg, WPARAM wPara
 }
 
 void win32SetupPrinter(GooString *printer, GooString *printOpt,
-		       GBool duplex, GBool setupdlg)
+		       bool duplex, bool setupdlg)
 {
   if (printer->getCString()[0] == 0) {
     DWORD size = 0;
-    GetDefaultPrinterA(NULL, &size);
+    GetDefaultPrinterA(nullptr, &size);
     printerName = (char*)gmalloc(size);
     GetDefaultPrinterA(printerName, &size);
   } else {
-    printerName = gstrndup(printer->getCString(), printer->getLength());
+    printerName = copyString(printer->getCString(), printer->getLength());
   }
 
   //Query the size of the DEVMODE struct
-  LONG szProp = DocumentPropertiesA(NULL, NULL, printerName, NULL, NULL, 0);
+  LONG szProp = DocumentPropertiesA(nullptr, nullptr, printerName, nullptr, nullptr, 0);
   if (szProp < 0) {
     fprintf(stderr, "Error: Printer \"%s\" not found\n", printerName);
     exit(99);
@@ -385,7 +386,7 @@ void win32SetupPrinter(GooString *printer, GooString *printOpt,
   devmode->dmSize = sizeof(DEVMODEA);
   devmode->dmSpecVersion = DM_SPECVERSION;
   //Load the current default configuration for the printer into devmode
-  if (DocumentPropertiesA(NULL, NULL, printerName, devmode, devmode, DM_OUT_BUFFER) < 0) {
+  if (DocumentPropertiesA(nullptr, nullptr, printerName, devmode, devmode, DM_OUT_BUFFER) < 0) {
     fprintf(stderr, "Error: Printer \"%s\" not found\n", printerName);
     exit(99);
   }
@@ -401,7 +402,7 @@ void win32SetupPrinter(GooString *printer, GooString *printOpt,
   DWORD mode = DM_IN_BUFFER | DM_OUT_BUFFER;
   if (setupdlg)
     mode |= DM_IN_PROMPT;
-  ret = DocumentPropertiesA(NULL, NULL, printerName, devmode, devmode, mode);
+  ret = DocumentPropertiesA(nullptr, nullptr, printerName, devmode, devmode, mode);
   if (ret < 0) {
     fprintf(stderr, "Error: Printer \"%s\" not found\n", printerName);
     exit(99);
@@ -409,15 +410,15 @@ void win32SetupPrinter(GooString *printer, GooString *printOpt,
   if (setupdlg && ret == IDCANCEL)
     exit(0);
 
-  hdc = CreateDCA(NULL, printerName, NULL, devmode);
+  hdc = CreateDCA(nullptr, printerName, nullptr, devmode);
   if (!hdc) {
     fprintf(stderr, "Error: Printer \"%s\" not found\n", printerName);
     exit(99);
   }
 }
 
-void win32ShowPrintDialog(GBool *expand, GBool *noShrink, GBool *noCenter,
-			  GBool *usePDFPageSize, GBool *allPages,
+void win32ShowPrintDialog(bool *expand, bool *noShrink, bool *noCenter,
+			  bool *usePDFPageSize, bool *allPages,
 			  int *firstPage, int *lastPage, int maxPages)
 {
   PRINTDLG pd;
@@ -454,21 +455,21 @@ void win32ShowPrintDialog(GBool *expand, GBool *noShrink, GBool *noCenter,
     devmode = (DEVMODEA*)GlobalLock(hDevmode);
     hdc = pd.hDC;
     if (pd.Flags & PD_PAGENUMS) {
-      *allPages = gFalse;
+      *allPages = false;
       *firstPage = pd.nFromPage;
       *lastPage = pd.nToPage;
     } else {
-      *allPages = gTrue;
+      *allPages = true;
     }
     if (pageScale == NONE) {
-      *expand = gFalse;
-      *noShrink = gTrue;
+      *expand = false;
+      *noShrink = true;
     } else if (pageScale == SHRINK) {
-      *expand = gFalse;
-      *noShrink = gFalse;
+      *expand = false;
+      *noShrink = false;
     } else {
-      *expand = gTrue;
-      *noShrink = gFalse;
+      *expand = true;
+      *noShrink = false;
     }
     *noCenter = !centerPage;
     *usePDFPageSize = useOrigPageSize;
@@ -497,11 +498,11 @@ cairo_surface_t *win32BeginDocument(GooString *inputFileName, GooString *outputF
   return cairo_win32_printing_surface_create(hdc);
 }
 
-void win32BeginPage(double *w, double *h, GBool changePageSize, GBool useFullPage)
+void win32BeginPage(double *w, double *h, bool changePageSize, bool useFullPage)
 {
   if (changePageSize)
     fillPagePrinterOptions(*w, *h);
-  if (DocumentPropertiesA(NULL, NULL, printerName, devmode, devmode, DM_IN_BUFFER | DM_OUT_BUFFER) < 0) {
+  if (DocumentPropertiesA(nullptr, nullptr, printerName, devmode, devmode, DM_IN_BUFFER | DM_OUT_BUFFER) < 0) {
     fprintf(stderr, "Error: Printer \"%s\" not found\n", printerName);
     exit(99);
   }
