@@ -1,5 +1,7 @@
 /*
  * Copyright (C) 2008, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2017, Adrian Johnson <ajohnson@redneon.com>
+ * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,10 +27,16 @@
 void printEncodings()
 {
   GooList *encNames = globalParams->getEncodingNames();
+
+  std::sort(encNames->begin(), encNames->end(), [](void *lhs, void *rhs) {
+    return static_cast<GooString *>(lhs)->cmp(static_cast<GooString *>(rhs)) < 0;
+  });
+
   printf("Available encodings are:\n");
   for (int i = 0; i < encNames->getLength(); ++i) {
     GooString *enc = (GooString*)encNames->get(i);
     printf("%s\n", enc->getCString());
   }
+
   delete encNames;
 }
